@@ -51,6 +51,10 @@ public:
 
   class Widget *add( class Widget *newelement, int tx = 0, int ty = 0, int tautosizeMode = ACONT_NONE );
   AContainer *add( AContainer *newcont, int tx = 0, int ty = 0 );
+  template <class T> T *addWidget( T *newelement, int tx = 0, int ty = 0, int tautosizeMode = ACONT_NONE )
+  {
+      return static_cast<T*>( add( newelement, tx, ty, tautosizeMode ) );
+  }
 
   void setParent( AContainer *nv );
   int remove( const AContainer *v );
