@@ -1,6 +1,6 @@
 /* aguix.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2016 Ralf Hoffmann.
+ * Copyright (C) 2001-2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -60,6 +60,29 @@ class TimeoutStore;
 enum {MES_WAIT,MES_GET};
 enum {NON_GADGET,CLOSE_GADGET,BUTTON_GADGET,SHADOW_GADGET,CHOOSE_GADGET,LISTVIEW,ONELVC,MORELVC,STRING_GADGET};
 
+struct AGUIX_XProperty {
+    AGUIX_XProperty() : success( true ),
+                        property_data( NULL ),
+                        type( None ),
+                        format( 0 ),
+                        number_of_items( 0 )
+    {}
+
+    void freeProperty()
+    {
+        if ( property_data ) {
+            XFree( property_data );
+            property_data = NULL;
+        }
+    }
+
+    bool success;
+    unsigned char *property_data;
+    Atom type;
+	int format;
+	unsigned long number_of_items;
+};
+
 class AGUIX {
 public:
   AGUIX( int argc, char **argv, const std::string &classname );
@@ -221,7 +244,18 @@ public:
     typedef enum { CLOSE_ATOM, NET_WM_NAME_ATOM, NET_WM_ICON_NAME_ATOM, TARGETS_ATOM,
                    NET_WM_WINDOW_TYPE, NET_WM_WINDOW_TYPE_DIALOG, NET_WM_WINDOW_TYPE_NORMAL,
                    UTF8_STRING, NET_WM_STATE, NET_WM_STATE_MAXIMIZED_HORZ,
-                   NET_WM_STATE_MAXIMIZED_VERT
+                   NET_WM_STATE_MAXIMIZED_VERT,
+                   XDNDENTER,
+                   XDNDPOSITION,
+                   XDNDSTATUS,
+                   XDNDTYPELIST,
+                   XDNDACTIONCOPY,
+                   XDNDDROP,
+                   XDNDLEAVE,
+                   XDNDFINISHED,
+                   XDNDSELECTION,
+                   XDNDPROXY,
+                   XDNDAWARE
     } atom_name_t;
   Atom getAtom( atom_name_t name ) const;
 
@@ -297,6 +331,12 @@ public:
 
     bool isValidScreenPosition( int x, int y,
                                 int w, int h );
+
+    void startXDND( Widget *initiator,
+                    Window w,
+                    unsigned int mouse_button );
+
+    void widgetDestroyed( Widget *w );
 private:
   Display *dsp;
   int scr;
@@ -312,7 +352,22 @@ private:
       XA_UTF8_STRING,
       XA_NET_WM_STATE,
       XA_NET_WM_STATE_MAXIMIZED_HORZ,
-      XA_NET_WM_STATE_MAXIMIZED_VERT;
+      XA_NET_WM_STATE_MAXIMIZED_VERT,
+      XA_XDNDENTER,
+      XA_XDNDPOSITION,
+      XA_XDNDSTATUS,
+      XA_XDNDTYPELIST,
+      XA_XDNDACTIONCOPY,
+      XA_XDNDDROP,
+      XA_XDNDLEAVE,
+      XA_XDNDFINISHED,
+      XA_XDNDSELECTION,
+      XA_XDNDPROXY,
+      XA_XDNDAWARE,
+      XA_MULTIPLE,
+      XA_TEXT_URI_LIST,
+      XA_TEXT_PLAIN;
+
   int m_argc;
   char **m_argv;
   std::string m_classname;
@@ -404,6 +459,28 @@ private:
 
   bool waitForEventOnFD( int ms );
 
+    AGUIX_XProperty getProperty( Window win,
+                                 Atom property );
+    Atom selectBestTargetForDND( Atom type1,
+                                 Atom type2,
+                                 Atom type3 );
+    Atom selectBestTargetForDND( AGUIX_XProperty type_list );
+    Atom selectBestTargetForDND( const std::vector< Atom > &list );
+
+    void handleXDNDEnter( XEvent *e );
+    void handleXDNDPosition( XEvent *e );
+    void handleXDNDLeave( XEvent *e );
+    void handleXDNDDrop( XEvent *e );
+    void handleXDNDStatus( XEvent *e );
+    void handleXDNDFinished( XEvent *e );
+    void cleanupDND();
+
+    void initXDNDTypes();
+
+    void processSelectionRequest( XEvent *e );
+    void setTargetsProperty( Window w, Atom property );
+    Window findXDNDAwareWindow( Window w, Window *return_proxy_window );
+
   int m_open_popup_counter;
   bool m_popup_ignore_button_release;
 
@@ -462,6 +539,71 @@ private:
         void disableExternalTimer();
     } m_external_timeouts;
 
+    struct aguix_xdnd_state {
+        aguix_xdnd_state() : drop_active( false ),
+                             source( None ),
+                             selected_target( None ),
+                             last_activity( 0 ),
+                             version( 0 ),
+                             target_awin( NULL ),
+                             sent_target_request( false ),
+                             target_widget( NULL ),
+                             drag_active( false ),
+                             drag_target_status( AGUIX_XDND_UNAWARE ),
+                             drag_initiator( NULL ),
+                             drag_initiator_window( None ),
+                             drag_current_target_window( None ),
+                             drag_current_target_version( -1 ),
+                             drag_current_proxy_target_window( None ),
+                             drop_pending( false ),
+                             mouse_button( Button1 ),
+                             position_silent( false ),
+                             position_silent_x( 0 ),
+                             position_silent_y( 0 ),
+                             position_silent_w( 0 ),
+                             position_silent_h( 0 )
+        {}
+
+        enum xdnd_target_status {
+            AGUIX_XDND_UNAWARE,
+            AGUIX_XDND_UNRESPONSIVE,
+            AGUIX_XDND_ACCEPT
+        };
+
+        bool drop_active;
+        Window source;
+        Atom selected_target;
+        time_t last_activity;
+        int version;
+        AWindow *target_awin;
+        bool sent_target_request;
+        Widget *target_widget;
+
+        bool drag_active;
+        enum xdnd_target_status drag_target_status;
+        Widget *drag_initiator;
+        Window drag_initiator_window;
+        Window drag_current_target_window;
+        int drag_current_target_version;
+
+        Window drag_current_proxy_target_window;
+
+        bool drop_pending;
+
+        unsigned int mouse_button;
+
+        bool position_silent;
+        int position_silent_x;
+        int position_silent_y;
+        int position_silent_w;
+        int position_silent_h;
+    }  m_xdnd;
+
+    std::map< std::string, int > m_xdnd_receive_types;
+
+    Cursor m_xcursor_plus;
+    Cursor m_xcursor_circle;
+
     int m_x_fd;
 };
 
