@@ -1,6 +1,6 @@
 /* awindow.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2016 Ralf Hoffmann.
+ * Copyright (C) 2001-2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -312,6 +312,7 @@ bool AWindow::handleMessage(XEvent *E,Message *msg)
   // return if we don't handle messages
   if ( ( getForbidInput() == true ) &&
        ( msg->type != Expose ) &&
+       ( msg->type != ConfigureNotify ) &&
        ( msg->type != FocusIn ) &&
        ( msg->type != FocusOut ) ) {
     // but only without lockElement or we don't own it
@@ -354,6 +355,11 @@ bool AWindow::handleMessage(XEvent *E,Message *msg)
       }
     }
   }
+
+  if ( msg->type == ConfigureNotify ) {
+      if ( getForbidInput() == true && conLock == false ) return returnvalue;
+  }
+  
   // Alle Element bekommen Nachricht
   res = 0;
   for ( childs_it it1 = _childs.begin(); it1 != _childs.end(); it1++ ) {
@@ -1546,3 +1552,71 @@ void AWindow::forceOpenPosition( int x, int y,
     m_open_max_v = max_v;
     m_force_open_position = true;
 }
+
+void AWindow::enableXDND()
+{
+    Atom version = 5;
+
+    XChangeProperty( _aguix->getDisplay(),
+                     win, _aguix->getAtom( AGUIX::XDNDAWARE ),
+                     XA_ATOM, 32,
+                     PropModeReplace, (unsigned char*)&version, 1 );
+
+    m_enable_xdnd = true;
+}
+
+bool AWindow::acceptXDND()
+{
+    return m_enable_xdnd;
+}
+
+Window AWindow::findWindowForRootPos( int rx, int ry )
+{
+    int x, y;
+    Window child;
+    Window previous_child = None;
+    Window current_window = win;
+
+    if ( XTranslateCoordinates( _aguix->getDisplay(),
+                                DefaultRootWindow( _aguix->getDisplay() ),
+                                current_window,
+                                rx, ry,
+                                &x, &y,
+                                &child ) != True ) {
+        return None;
+    }
+
+    previous_child = child;
+
+    while ( child != None ) {
+        previous_child = child;
+
+        if ( XTranslateCoordinates( _aguix->getDisplay(),
+                                    current_window,
+                                    child,
+                                    x, y,
+                                    &x, &y,
+                                    &child ) != True ) {
+            return None;
+        }
+
+        current_window = previous_child;
+    }
+
+    return previous_child;
+}
+
+Widget *AWindow::findWidgetForRootPos( int rx, int ry )
+{
+    Window child_win = findWindowForRootPos( rx, ry );
+
+    if ( child_win == None ) return NULL;
+
+    Widget *w = findWidgetForWindow( child_win );
+
+    if ( AWindow *awin = dynamic_cast< AWindow * >( w ) ) {
+        return awin->findWidgetForWindow( child_win );
+    }
+
+    return w;
+}
