@@ -1,6 +1,6 @@
 /* cyclebutton.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2007,2009-2010,2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -32,7 +32,7 @@ CycleButton::~CycleButton()
 }
 
 CycleButton::CycleButton(AGUIX *taguix,int tx,int ty,int width,
-                         int tfg,int tbg,int tdata):GUIElement(taguix)
+                         int tdata):GUIElement(taguix)
 {
   int bw;
 
@@ -45,8 +45,8 @@ CycleButton::CycleButton(AGUIX *taguix,int tx,int ty,int width,
   this->data=tdata;
   this->state=0;
   this->instate=0;
-  this->fg=tfg;
-  this->bg=tbg;
+  this->fg = _aguix->getFaces().getColor( "button-fg" );
+  this->bg = _aguix->getFaces().getColor( "button-bg" );
 
   font=NULL;
   act_opt=-1;
@@ -55,7 +55,7 @@ CycleButton::CycleButton(AGUIX *taguix,int tx,int ty,int width,
 }
 
 CycleButton::CycleButton(AGUIX *taguix,int tx,int ty,int width,int height,
-                         int tfg,int tbg,int tdata):GUIElement(taguix)
+                         int tdata):GUIElement(taguix)
 {
   _x=tx;
   _y=ty;
@@ -64,8 +64,8 @@ CycleButton::CycleButton(AGUIX *taguix,int tx,int ty,int width,int height,
   this->data=tdata;
   this->state=0;
   this->instate=0;
-  this->fg=tfg;
-  this->bg=tbg;
+  this->fg = _aguix->getFaces().getColor( "button-fg" );
+  this->bg = _aguix->getFaces().getColor( "button-bg" );
 
   font=NULL;
   act_opt=-1;
@@ -177,7 +177,7 @@ void CycleButton::redraw()
   
   bw = 2;
   
-  _aguix->setFG( 1 );
+  _aguix->setFG( _aguix->getFaceCol_default_fg() );
   for ( int i = 0; i < 11; i++ ) {
     x1 = circle[i][0];
     x2 = circle[i][2];
