@@ -1,6 +1,6 @@
 /* karteibutton.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2004-2011,2013 Ralf Hoffmann.
+ * Copyright (C) 2004-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -35,14 +35,10 @@ KarteiButton::KarteiButton( AGUIX *taguix,
 			    int tx,
 			    int ty,
 			    int width,
-			    int tfg,
-			    int tbg,
 			    int tdata ) : CycleButton( taguix,
 						       tx,
 						       ty,
 						       width,
-						       tfg,
-						       tbg,
 						       tdata )
 {
   int bw;
@@ -54,6 +50,9 @@ KarteiButton::KarteiButton( AGUIX *taguix,
   bw = 2;
 
   _h = taguix->getCharHeight() + 2 * bw;
+
+  fg = _aguix->getFaces().getColor( "default-fg" );
+  bg = _aguix->getFaces().getColor( "default-bg" );
 }
 
 KarteiButton::KarteiButton( AGUIX *taguix,
@@ -61,20 +60,19 @@ KarteiButton::KarteiButton( AGUIX *taguix,
 			    int ty,
 			    int width,
 			    int height,
-			    int tfg,
-			    int tbg,
 			    int tdata ) : CycleButton( taguix,
 						       tx,
 						       ty,
 						       width,
 						       height,
-						       tfg,
-						       tbg,
 						       tdata )
 {
   optionChangeCallback = NULL;
   k2 = NULL;
   focusPos = 0;
+
+  fg = _aguix->getFaces().getColor( "default-fg" );
+  bg = _aguix->getFaces().getColor( "default-bg" );
 }
 
 void KarteiButton::redraw()
@@ -219,16 +217,16 @@ void KarteiButton::redraw()
 	    _aguix->DrawTriangleFilled( win, usegc, sx , sy, sx + dx, sy, sx + dx, basey );
 	  }
 	} else if ( i == act_opt ) {
-	  _aguix->setFG( usegc, 0 );
+	  _aguix->setFG( usegc, _aguix->getFaces().getColor( "default-bg" ) );
 	  
 	  // for active option overdraw right part of previous option
 	  _aguix->DrawTriangleFilled( win, usegc, basex , basey, sx + dx, basey, sx + dx, 0 );
 	}
       } else {
-	_aguix->setFG( usegc, 2 );
-	_aguix->DrawLine( win, usegc,
-			  sx, sy,
-			  sx + dx, 0 );
+          _aguix->setFG( usegc, _aguix->getFaceCol_3d_bright() );
+          _aguix->DrawLine( win, usegc,
+                            sx, sy,
+                            sx + dx, 0 );
       }
       
       const char *tstr = options[i].c_str();
@@ -267,10 +265,10 @@ void KarteiButton::redraw()
 	  _aguix->DrawTriangleFilled( win, usegc, sx + dx + dx2 , 0, sx + dx + dx2, basey, sx + dx + dx2 + 2 * delx, basey );
 	}
       } else {
-	_aguix->setFG( usegc, 1 );
-	_aguix->DrawLine( win, usegc,
-			  sx + dx + dx2, 0,
-			  ex, ey );
+          _aguix->setFG( usegc, _aguix->getFaceCol_3d_dark() );
+          _aguix->DrawLine( win, usegc,
+                            sx + dx + dx2, 0,
+                            ex, ey );
       }
       
       if ( i == act_opt ) {
@@ -281,9 +279,11 @@ void KarteiButton::redraw()
       if ( run != 0 ) {
           if ( m_shrinker.getVal() != NULL ) {
               std::string current_text = m_shrinker->shrink( tstr, m_width_per_option[i], lencalc );
-              _aguix->DrawText( dc, font, current_text.c_str(), sx + dx + delx, 1, 1 );
+              _aguix->DrawText( dc, font, current_text.c_str(), sx + dx + delx, 1,
+                                _aguix->getFaceCol_default_fg() );
           } else {
-              _aguix->DrawText( dc, font, tstr, sx + dx + delx, 1, 1 );
+              _aguix->DrawText( dc, font, tstr, sx + dx + delx, 1,
+                                _aguix->getFaceCol_default_fg() );
           }
       }
 
@@ -291,7 +291,7 @@ void KarteiButton::redraw()
 	if ( ( getAcceptFocus() == true ) &&
 	     ( getHasFocus() == true ) &&
 	     ( focusPos == i ) ) {
-	  _aguix->setDottedFG( 1 );
+	  _aguix->setDottedFG( _aguix->getFaceCol_default_fg() );
 	  _aguix->DrawDottedRectangle( win, sx + dx + delx - 2, 1, dx2 - 2 * delx + 4, 1 + ch + 1 );
 	}
       }
@@ -301,7 +301,7 @@ void KarteiButton::redraw()
   }
   
   if ( ( act_x1 >= 0 ) && ( act_x2 > act_x1 ) ) {
-    _aguix->setFG( usegc, 2 );
+    _aguix->setFG( usegc, _aguix->getFaceCol_3d_bright() );
     _aguix->DrawLine( win, usegc, 0, basey, act_x1, basey );
     _aguix->DrawLine( win, usegc, act_x2 + 1, basey, _w, basey );
   }
