@@ -976,7 +976,7 @@ void PopUpMenu::removeLastInfixChar()
     } else {
         try {
             m_infix_filter.erase( prev_char );
-        } catch ( std::out_of_range ) {
+        } catch ( std::out_of_range & ) {
             m_infix_filter = "";
         }
     }
