@@ -1,6 +1,6 @@
 /* popupwindow.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2007,2012-2013 Ralf Hoffmann.
+ * Copyright (C) 2007-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -28,14 +28,19 @@ PopUpWindow::PopUpWindow( AGUIX *parent,
                           int y,
                           int width,
                           int height,
-                          int bg,
                           std::string title,
-                          int group_id ) : AWindow( parent, x, y, width, height, bg, title, AWindow::AWINDOW_DIALOG ),
+                          int group_id ) : AWindow( parent, x, y, width, height, title, AWindow::AWINDOW_DIALOG ),
                                            m_group_id( group_id ),
                                            m_prev_revert_to( 0 ),
                                            m_prev_focus( 0 ),
                                            m_old_focus_got( false )
 {
+    int tbg = _aguix->getFaces().getColor( "popup-bg" );
+
+    if ( tbg >= 0 ) {
+        _bg = tbg;
+    }
+
     if ( m_group_id == -1 ) {
         m_group_id = group_id_counter++;
         if ( group_id_counter == -1 )
