@@ -1,6 +1,6 @@
 /* textstorage.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2005-2009,2011 Ralf Hoffmann.
+ * Copyright (C) 2005-2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -21,16 +21,26 @@
 
 #include "textstorage.h"
 #include "utf8.hh"
+#include "util.h"
 
-TextStorageString::TextStorageString( const char *buf, int len, const RefCount<AWidth> &lencalc, int line_limit ) : m_lencalc( lencalc ),
-                                                                                                                    m_current_line_limit( -1 )
+TextStorageString::TextStorageString( const char *buf,
+                                      int len,
+                                      const RefCount<AWidth> &lencalc,
+                                      int line_limit,
+                                      enum text_storage_converion convert ) : m_convert( convert ),
+                                                                              m_lencalc( lencalc ),
+                                                                              m_current_line_limit( -1 )
 {
   std::string s1( buf, len );
   initBuffer( s1, line_limit );
 }
 
-TextStorageString::TextStorageString( const std::string &content, const RefCount<AWidth> &lencalc, int line_limit ) : m_lencalc( lencalc ),
-                                                                                                                      m_current_line_limit( -1 )
+TextStorageString::TextStorageString( const std::string &content,
+                                      const RefCount<AWidth> &lencalc,
+                                      int line_limit,
+                                      enum text_storage_converion convert ) : m_convert( convert ),
+                                                                              m_lencalc( lencalc ),
+                                                                              m_current_line_limit( -1 )
 {
     initBuffer( content, line_limit );
 }
@@ -83,7 +93,14 @@ void TextStorageString::initBuffer( const std::string &content, int line_limit_w
   unsigned int i;
   int current_line = 0, current_subline = 0;
 
-  buffer = content;
+  if ( m_convert != NO_CHARACTER_CONVERSION ) {
+      m_raw_buffer = content;
+
+      convertRawData();
+  } else {
+      buffer = content;
+  }
+  
   line_offsets.clear();
   line_offsets.push_back( 0 );
   _real_lines.clear();
@@ -253,7 +270,10 @@ void TextStorageString::setLineLimit( int new_limit )
     if ( new_limit == m_current_line_limit ) return;
     
     if ( new_limit < -1 ) new_limit = -1;
-    initBuffer( buffer, new_limit );
+
+    std::string old_data( buffer );
+    
+    initBuffer( old_data, new_limit );
 }
 
 int TextStorageString::getLineLimit()
@@ -318,7 +338,8 @@ int TextStorageString::getNrOfUnwrappedLines() const
 int TextStorageString::getUnwrappedLine( int line_nr,
                                          unsigned int offset,
                                          int len,
-                                         std::string &return_line ) const
+                                         std::string &return_line,
+                                         bool raw ) const
 {
     unsigned int start_offset, line_len;  // remember offset from line_offsets are not necessarly inside buffer
     
@@ -345,12 +366,39 @@ int TextStorageString::getUnwrappedLine( int line_nr,
             // line limiter given
             if ( (unsigned int )len < line_len ) line_len = (unsigned int)len;
         }
-        if ( ( start_offset < buffer.length() ) && ( line_len > 0 ) )
-            return_line.append( buffer, start_offset, line_len );
+
+        if ( m_convert != NO_CHARACTER_CONVERSION && raw ) {
+            if ( start_offset < m_converted_pos_to_raw.size() && line_len > 0 ) {
+                size_t raw_start = m_converted_pos_to_raw.at( start_offset );
+
+                size_t raw_end = start_offset + line_len;
+
+                if ( raw_end >= m_converted_pos_to_raw.size() ) {
+                    raw_end = m_converted_pos_to_raw.size() - 1;
+                }
+                raw_end = m_converted_pos_to_raw.at( raw_end );
+
+                return_line.append( m_raw_buffer, raw_start, raw_end - raw_start );
+            }
+        } else {
+            if ( ( start_offset < buffer.length() ) && ( line_len > 0 ) ) {
+                return_line.append( buffer, start_offset, line_len );
+            }
+        }
     }
     return 0;
 }
 
+int TextStorageString::getUnwrappedLine( int line_nr,
+                                         unsigned int offset,
+                                         int len,
+                                         std::string &return_line ) const
+{
+    return getUnwrappedLine( line_nr, offset,
+                             len,
+                             return_line, false );
+}
+
 int TextStorageString::getUnwrappedLine( int line_nr,
                                          unsigned int offset,
                                          std::string &return_line ) const
@@ -358,6 +406,23 @@ int TextStorageString::getUnwrappedLine( int line_nr,
     return getUnwrappedLine( line_nr, offset, -1, return_line );
 }
 
+int TextStorageString::getUnwrappedLineRaw( int line_nr,
+                                            unsigned int offset,
+                                            int len,
+                                            std::string &return_line ) const
+{
+    return getUnwrappedLine( line_nr, offset,
+                             len,
+                             return_line, true );
+}
+
+int TextStorageString::getUnwrappedLineRaw( int line_nr,
+                                            unsigned int offset,
+                                            std::string &return_line ) const
+{
+    return getUnwrappedLineRaw( line_nr, offset, -1, return_line );
+}
+
 int TextStorageString::getUnwrappedLineCharacters( int line_nr ) const
 {
     unsigned int start_offset, line_len;  // remember offset from line_offsets are not necessarly inside buffer
@@ -420,3 +485,97 @@ void TextStorageString::setContent( const std::string &content )
 {
     initBuffer( content, m_current_line_limit );
 }
+
+std::string TextStorageString::getReplacementString( unsigned char ch, size_t column ) const
+{
+    if ( ch == '\t' ) {
+        return std::string( 8 - column % 8, ' ' );
+    }
+
+    if ( m_convert == CONVERT_NON_PRINTABLE_HEX ) {
+        return AGUIXUtils::formatStringToString( "<0x%02x>", ch );
+    }
+
+    return ".";    
+}
+
+void TextStorageString::convertRawData()
+{
+    if ( m_convert == NO_CHARACTER_CONVERSION ) return;
+
+    size_t len = m_raw_buffer.length();
+    size_t pos = 0;
+    size_t cl;
+    const char *cstr = m_raw_buffer.c_str();
+
+    buffer = "";
+    m_converted_pos_to_raw.clear();
+
+    size_t column = 0;
+
+    while ( pos < len ) {
+        if ( cstr[pos] >= 0 && cstr[pos] <= 127 ) {
+            if ( std::isprint( cstr[pos] ) ) {
+                m_converted_pos_to_raw.push_back( pos );
+                buffer += cstr[pos++];
+                column++;
+            } else if ( cstr[pos] == '\n' ) {
+                m_converted_pos_to_raw.push_back( pos );
+                buffer += cstr[pos++];
+                column = 0;
+            } else {
+                std::string replacement = getReplacementString( cstr[pos], column );
+                for ( size_t i = 0; i < replacement.length(); i++ ) {
+                    m_converted_pos_to_raw.push_back( pos);
+                    buffer += replacement[i];
+                    column++;
+                }
+                pos++;
+            }
+        } else {
+            cl = UTF8::getLenOfCharacter( cstr + pos );
+
+            if ( cl <= 1 ) {
+                if ( UTF8::isValidCharacter( cstr + pos ) ) {
+                    m_converted_pos_to_raw.push_back( pos );
+                    buffer += cstr[pos++];
+                    column++;
+                } else {
+                    // invalid
+                    std::string replacement = getReplacementString( cstr[pos], column );
+                    for ( size_t i = 0; i < replacement.length(); i++ ) {
+                        m_converted_pos_to_raw.push_back( pos);
+                        buffer += replacement[i];
+                        column++;
+                    }
+                    pos++;
+                }
+            } else {
+                size_t base_pos = pos;
+                while ( cl > 0 && pos < len ) {
+                    m_converted_pos_to_raw.push_back( base_pos );
+                    buffer += cstr[pos++];
+                    cl--;
+                }
+                column++;
+            }
+        }
+    }
+
+    m_converted_pos_to_raw.push_back( pos );
+}
+
+void TextStorageString::setConvertMode( enum text_storage_converion convert )
+{
+    std::string old_data;
+
+    if ( m_convert == NO_CHARACTER_CONVERSION ) {
+        old_data = buffer;
+    } else {
+        old_data = m_raw_buffer;
+    }
+    
+    m_convert = convert;
+
+    initBuffer( old_data, m_current_line_limit );
+}
