@@ -1,6 +1,6 @@
 /* textstorage.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2005-2009 Ralf Hoffmann.
+ * Copyright (C) 2005-2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -52,14 +52,34 @@ class TextStorage
   virtual int getUnwrappedLine( int line_nr,
                                 unsigned int offset,
                                 std::string &return_line ) const = 0;
+  virtual int getUnwrappedLineRaw( int line_nr,
+                                   unsigned int offset,
+                                   int len,
+                                   std::string &return_line ) const = 0;
+  virtual int getUnwrappedLineRaw( int line_nr,
+                                   unsigned int offset,
+                                   std::string &return_line ) const = 0;
   virtual std::pair< std::pair< int, int >, int > getLineForOffset( int unwrapped_line_nr, int line_offset ) const = 0;
 };
 
 class TextStorageString : public TextStorage
 {
  public:
-  TextStorageString( const std::string &content, const RefCount<AWidth> &lencalc, int line_limit = -1 );
-  TextStorageString( const char *buf, int len, const RefCount<AWidth> &lencalc, int line_limit = -1 );
+    enum text_storage_converion {
+        NO_CHARACTER_CONVERSION,
+        CONVERT_NON_PRINTABLE_SIMPLE,
+        CONVERT_NON_PRINTABLE_HEX
+    };
+    
+  TextStorageString( const std::string &content,
+                     const RefCount<AWidth> &lencalc,
+                     int line_limit = -1,
+                     enum text_storage_converion convert = NO_CHARACTER_CONVERSION );
+  TextStorageString( const char *buf,
+                     int len,
+                     const RefCount<AWidth> &lencalc,
+                     int line_limit = -1,
+                     enum text_storage_converion convert = NO_CHARACTER_CONVERSION );
 
   int getNrOfLines() const;
   int getLine( int line_nr, unsigned int offset, int len, std::string &return_line ) const;
@@ -80,13 +100,29 @@ class TextStorageString : public TextStorage
   int getUnwrappedLine( int line_nr,
                         unsigned int offset,
                         std::string &return_line ) const;
+  int getUnwrappedLineRaw( int line_nr,
+                           unsigned int offset,
+                           int len,
+                           std::string &return_line ) const;
+  int getUnwrappedLineRaw( int line_nr,
+                           unsigned int offset,
+                           std::string &return_line ) const;
   std::pair< std::pair< int, int >, int > getLineForOffset( int unwrapped_line_nr, int line_offset ) const;
 
   void setContent( const std::string &content );
+
+    void setConvertMode( enum text_storage_converion convert );
  private:
   void initBuffer( const std::string &content, int line_limit_width = -1 );
   unsigned int getTokenLen( unsigned int start_offset );
+    std::string getReplacementString( unsigned char ch, size_t column ) const;
   
+    void convertRawData();
+
+    enum text_storage_converion m_convert;
+    std::string m_raw_buffer;   // this is the unmodified original data
+    std::vector< size_t > m_converted_pos_to_raw;     // lookup table from pos within buffer to pos within raw_buffer
+
   std::string buffer;                      // stores text file
   std::vector<unsigned int> line_offsets;  // stores offset for each line (can be outside of buffer
                                            // for last line)
@@ -99,6 +135,11 @@ class TextStorageString : public TextStorage
    */
   std::vector<unsigned int> m_unwrapped_line_offsets;
   int getUnwrappedLineCharacters( int line_nr ) const;
+  int getUnwrappedLine( int line_nr,
+                        unsigned int offset,
+                        int len,
+                        std::string &return_line,
+                        bool raw ) const;
 
   //TODO better remove const modifier from getLineWidth and co?
   //     instead of declaring the cache mutable?
