@@ -341,14 +341,19 @@ static bool linePairEQ( const std::pair< int, int > &p1,
 }
 
 void TextView::redraw()
+{
+  if ( isCreated() == false ) return;
+  if ( isVisible() == false ) return;
+
+  forceRedraw();
+}
+
+void TextView::forceRedraw()
 {
   int tx, ty, lines, width, basetx;
   int bw;
   std::pair<int,int> real_line( -1, -1 );
 
-  if ( isCreated() == false ) return;
-  if ( isVisible() == false ) return;
-
   checkBuffer();
   
   boxRedraw();
