@@ -1,6 +1,6 @@
 /* utf8.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2006-2015 Ralf Hoffmann.
+ * Copyright (C) 2006-2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -303,3 +303,36 @@ std::string UTF8::convertToValidCharacterString( const char *str )
 
     return res;
 }
+
+int UTF8::movePosBackToValidPos( const char *str, int pos )
+{
+    if ( pos < 0 ) return -1;
+
+    for ( ; pos > 0; pos-- ) {
+        char ch = str[ pos ];
+
+        if ( ch == '\0' ) break;
+
+        // high-bit not set is a valid utf8 character and latin1
+        if ( ch >= 0 ) break;
+
+#ifndef DISABLE_UTF8_SUPPORT
+        if ( UTF8::getUTF8Mode() != UTF8::UTF8_DISABLED && UTF8::getCurrentEncoding() == UTF8::ENCODING_UTF8 ) {
+            //TODO
+            if ( ( ch & 0xc0 ) == 0xc0 ) {
+                // first two high bits set so this is a multibyte lead byte
+                break;
+            }
+
+            // this is a continuation byte so reduce len by falling through
+        } else {
+#endif
+            // without utf8 support any byte is valid
+            break;
+#ifndef DISABLE_UTF8_SUPPORT
+        }
+#endif
+    }
+
+    return pos;
+}
