@@ -1,6 +1,6 @@
 /* chmodowncore.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2013 Ralf Hoffmann.
+ * Copyright (C) 2013-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -398,7 +398,7 @@ int ChModOwnCore::requestNewMode( const FileEntry &fe, changemod_info_t *return_
     char *tstr;
     
     tmode = ( ( fe.isLink == true ) && ( fe.isCorrupt == false ) ) ? fe.dmode() : fe.mode();
-    win = new AWindow( m_aguix, 10, 10, 10, 10, 0, catalog.getLocaleCom( 38 ), AWindow::AWINDOW_DIALOG );
+    win = new AWindow( m_aguix, 10, 10, 10, 10, catalog.getLocaleCom( 38 ), AWindow::AWINDOW_DIALOG );
     win->create();
     
     AContainer *ac1 = win->setContainer( new AContainer( win, 1, 4 ), true );
@@ -408,18 +408,18 @@ int ChModOwnCore::requestNewMode( const FileEntry &fe, changemod_info_t *return_
     tstr=(char*)_allocsafe(strlen(catalog.getLocale(213))+strlen(fe.fullname)+1);
     sprintf(tstr,catalog.getLocale(213),fe.fullname);
     
-    ac1->add( new Text( m_aguix, 0, 0, tstr, 1 ), 0, 0, AContainer::CO_INCWNR );
+    ac1->add( new Text( m_aguix, 0, 0, tstr ), 0, 0, AContainer::CO_INCWNR );
     _freesafe(tstr);
     
     AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 1 );
     ac1_1->setMinSpace( 5 );
     ac1_1->setMaxSpace( 5 );
 
-    ac1_1->add( new Text( m_aguix, 0, 0, catalog.getLocale( 780 ), 1 ), 0, 0, AContainer::CO_FIX );
+    ac1_1->add( new Text( m_aguix, 0, 0, catalog.getLocale( 780 ) ), 0, 0, AContainer::CO_FIX );
     CycleButton *apply_mode_cb = static_cast<CycleButton*>( ac1_1->add( new CycleButton( m_aguix,
                                                                                          0, 0,
                                                                                          10,
-                                                                                         1, 0, 0 ),
+                                                                                         0 ),
                                                                         1, 0, AContainer::CO_FIX ) );
     apply_mode_cb->addOption( catalog.getLocale( 781 ) );
     apply_mode_cb->addOption( catalog.getLocale( 782 ) );
@@ -432,55 +432,55 @@ int ChModOwnCore::requestNewMode( const FileEntry &fe, changemod_info_t *return_
     ac1_2->setMinSpace( 5 );
     ac1_2->setMaxSpace( 5 );
     
-    ac1_2->add( new Text( m_aguix, 0, 0, catalog.getLocale( 218 ), 1 ), 1, 0, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
-    ac1_2->add( new Text( m_aguix, 0, 0, catalog.getLocale( 219 ), 1 ), 2, 0, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
-    ac1_2->add( new Text( m_aguix, 0, 0, catalog.getLocale( 220 ), 1 ), 3, 0, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
+    ac1_2->add( new Text( m_aguix, 0, 0, catalog.getLocale( 218 ) ), 1, 0, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
+    ac1_2->add( new Text( m_aguix, 0, 0, catalog.getLocale( 219 ) ), 2, 0, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
+    ac1_2->add( new Text( m_aguix, 0, 0, catalog.getLocale( 220 ) ), 3, 0, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
     
-    ac1_2->add( new Text( m_aguix, 0, 0, catalog.getLocale( 214 ), 1 ), 0, 1, AContainer::CO_FIX );
-    ac1_2->add( new Text( m_aguix, 0, 0, catalog.getLocale( 215 ), 1 ), 0, 2, AContainer::CO_FIX );
-    ac1_2->add( new Text( m_aguix, 0, 0, catalog.getLocale( 216 ), 1 ), 0, 3, AContainer::CO_FIX );
-    ac1_2->add( new Text( m_aguix, 0, 0, catalog.getLocale( 217 ), 1 ), 0, 5, AContainer::CO_FIX );
+    ac1_2->add( new Text( m_aguix, 0, 0, catalog.getLocale( 214 ) ), 0, 1, AContainer::CO_FIX );
+    ac1_2->add( new Text( m_aguix, 0, 0, catalog.getLocale( 215 ) ), 0, 2, AContainer::CO_FIX );
+    ac1_2->add( new Text( m_aguix, 0, 0, catalog.getLocale( 216 ) ), 0, 3, AContainer::CO_FIX );
+    ac1_2->add( new Text( m_aguix, 0, 0, catalog.getLocale( 217 ) ), 0, 5, AContainer::CO_FIX );
     
-    ac1_2->add( new Text( m_aguix, 0, 0, catalog.getLocale( 221 ), 1 ), 1, 4, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
-    ac1_2->add( new Text( m_aguix, 0, 0, catalog.getLocale( 222 ), 1 ), 2, 4, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
-    ac1_2->add( new Text( m_aguix, 0, 0, catalog.getLocale( 223 ), 1 ), 3, 4, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
+    ac1_2->add( new Text( m_aguix, 0, 0, catalog.getLocale( 221 ) ), 1, 4, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
+    ac1_2->add( new Text( m_aguix, 0, 0, catalog.getLocale( 222 ) ), 2, 4, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
+    ac1_2->add( new Text( m_aguix, 0, 0, catalog.getLocale( 223 ) ), 3, 4, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
     
     mcb[0] = (ChooseButton*)ac1_2->add( new ChooseButton( m_aguix, 0, 0,
                                                           ( ( tmode & S_IRUSR ) == 0 ) ? 0 : 1,
-                                                          "", LABEL_RIGHT, 0, 0 ), 1, 1, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
+                                                          "", LABEL_RIGHT, 0 ), 1, 1, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
     mcb[1] = (ChooseButton*)ac1_2->add( new ChooseButton( m_aguix, 0, 0,
                                                           ( ( tmode & S_IWUSR ) == 0 ) ? 0 : 1,
-                                                          "", LABEL_RIGHT, 0, 0 ), 2, 1, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
+                                                          "", LABEL_RIGHT, 0 ), 2, 1, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
     mcb[2] = (ChooseButton*)ac1_2->add( new ChooseButton( m_aguix, 0, 0,
                                                           ( ( tmode & S_IXUSR ) == 0 ) ? 0 : 1,
-                                                          "", LABEL_RIGHT, 0, 0 ), 3, 1, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
+                                                          "", LABEL_RIGHT, 0 ), 3, 1, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
     mcb[3] = (ChooseButton*)ac1_2->add( new ChooseButton( m_aguix, 0, 0,
                                                           ( ( tmode & S_IRGRP ) == 0 ) ? 0 : 1,
-                                                          "", LABEL_RIGHT, 0, 0 ), 1, 2, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
+                                                          "", LABEL_RIGHT, 0 ), 1, 2, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
     mcb[4] = (ChooseButton*)ac1_2->add( new ChooseButton( m_aguix, 0, 0,
                                                           ( ( tmode & S_IWGRP ) == 0 ) ? 0 : 1,
-                                                          "", LABEL_RIGHT, 0, 0 ), 2, 2, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
+                                                          "", LABEL_RIGHT, 0 ), 2, 2, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
     mcb[5] = (ChooseButton*)ac1_2->add( new ChooseButton( m_aguix, 0, 0,
                                                           ( ( tmode & S_IXGRP ) == 0 ) ? 0 : 1,
-                                                          "", LABEL_RIGHT, 0, 0 ), 3, 2, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
+                                                          "", LABEL_RIGHT, 0 ), 3, 2, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
     mcb[6] = (ChooseButton*)ac1_2->add( new ChooseButton( m_aguix, 0, 0,
                                                           ( ( tmode & S_IROTH ) == 0 ) ? 0 : 1,
-                                                          "", LABEL_RIGHT, 0, 0 ), 1, 3, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
+                                                          "", LABEL_RIGHT, 0 ), 1, 3, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
     mcb[7] = (ChooseButton*)ac1_2->add( new ChooseButton( m_aguix, 0, 0,
                                                           ( ( tmode & S_IWOTH ) == 0 ) ? 0 : 1,
-                                                          "", LABEL_RIGHT, 0, 0 ), 2, 3, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
+                                                          "", LABEL_RIGHT, 0 ), 2, 3, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
     mcb[8] = (ChooseButton*)ac1_2->add( new ChooseButton( m_aguix, 0, 0,
                                                           ( ( tmode & S_IXOTH ) == 0 ) ? 0 : 1,
-                                                          "", LABEL_RIGHT, 0, 0 ), 3, 3, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
+                                                          "", LABEL_RIGHT, 0 ), 3, 3, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
     mcb[9] = (ChooseButton*)ac1_2->add( new ChooseButton( m_aguix, 0, 0,
                                                           ( ( tmode & S_ISUID ) == 0 ) ? 0 : 1,
-                                                          "", LABEL_RIGHT, 0, 0 ), 1, 5, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
+                                                          "", LABEL_RIGHT, 0 ), 1, 5, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
     mcb[10] = (ChooseButton*)ac1_2->add( new ChooseButton( m_aguix, 0, 0,
                                                            ( ( tmode & S_ISGID ) == 0 ) ? 0 : 1,
-                                                           "", LABEL_RIGHT, 0, 0 ), 2, 5, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
+                                                           "", LABEL_RIGHT, 0 ), 2, 5, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
     mcb[11] = (ChooseButton*)ac1_2->add( new ChooseButton( m_aguix, 0, 0,
                                                            ( ( tmode & S_ISVTX ) == 0 ) ? 0 : 1,
-                                                           "", LABEL_RIGHT, 0, 0 ), 3, 5, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
+                                                           "", LABEL_RIGHT, 0 ), 3, 5, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
     setChooseButtonMatrixForMode( mcb, tmode );
     
     AContainer *ac1_3 = ac1->add( new AContainer( win, 4, 1 ), 0, 3 );
@@ -491,29 +491,21 @@ int ChModOwnCore::requestNewMode( const FileEntry &fe, changemod_info_t *return_
                                                   0,
                                                   0,
                                                   catalog.getLocale( 11 ),
-                                                  1,
-                                                  0,
                                                   0 ), 0, 0, AContainer::CO_FIX );
     Button *ok2allb = (Button*)ac1_3->add( new Button( m_aguix,
                                                        0,
                                                        0,
                                                        catalog.getLocale( 224 ),
-                                                       1,
-                                                       0,
                                                        0 ), 1, 0, AContainer::CO_FIX );
     Button *skipb = (Button*)ac1_3->add( new Button( m_aguix,
                                                      0,
                                                      0,
                                                      catalog.getLocale( 225 ),
-                                                     1,
-                                                     0,
                                                      0 ), 2, 0, AContainer::CO_FIX );
     Button *cb = (Button*)ac1_3->add( new Button( m_aguix,
                                                   0,
                                                   0,
                                                   catalog.getLocale( 8 ),
-                                                  1,
-                                                  0,
                                                   0 ), 3, 0, AContainer::CO_FIX );
     win->setDoTabCycling( true );
     win->contMaximize( true, true );
@@ -682,18 +674,18 @@ int ChModOwnCore::requestNewOwner( const FileEntry &fe, uid_t *return_owner, gid
 
     ttw = tth = 10;
     ttx = tty = 5;
-    win = new AWindow( m_aguix, 10, 10, ttw, tth, 0, catalog.getLocaleCom( 43 ), AWindow::AWINDOW_DIALOG );
+    win = new AWindow( m_aguix, 10, 10, ttw, tth, catalog.getLocaleCom( 43 ), AWindow::AWINDOW_DIALOG );
     win->create();
     tstr = (char*)_allocsafe( strlen( catalog.getLocale( 448 ) ) + strlen( fe.fullname ) + 1 );
     sprintf( tstr, catalog.getLocale( 448 ), fe.fullname );
 
-    ttext = (Text*)win->add( new Text( m_aguix, ttx, tty, tstr, 1 ) );
+    ttext = (Text*)win->add( new Text( m_aguix, ttx, tty, tstr ) );
     _freesafe( tstr );
   
     tty += ttext->getHeight() + 5;
   
-    utext = (Text*)win->add( new Text( m_aguix, ttx, tty, catalog.getLocale( 214 ), 1 ) );
-    gtext = (Text*)win->add( new Text( m_aguix, ttx, tty, catalog.getLocale( 215 ), 1 ) );
+    utext = (Text*)win->add( new Text( m_aguix, ttx, tty, catalog.getLocale( 214 ) ) );
+    gtext = (Text*)win->add( new Text( m_aguix, ttx, tty, catalog.getLocale( 215 ) ) );
     tty += utext->getHeight() + 5;
 
     lvu = (FieldListView*)win->add( new FieldListView( m_aguix, ttx, tty, 50, 10 * m_aguix->getCharHeight(), 0 ) );
@@ -761,29 +753,21 @@ int ChModOwnCore::requestNewOwner( const FileEntry &fe, uid_t *return_owner, gid
                                          5,
                                          tty,
                                          catalog.getLocale( 11 ),
-                                         1,
-                                         0,
                                          0 ) );
     ok2allb = (Button*)win->add( new Button( m_aguix,
                                              0,
                                              tty,
                                              catalog.getLocale( 224 ),
-                                             1,
-                                             0,
                                              0 ) );
     skipb = (Button*)win->add( new Button( m_aguix,
                                            0,
                                            tty,
                                            catalog.getLocale( 225 ),
-                                           1,
-                                           0,
                                            0 ) );
     cb = (Button*)win->add( new Button( m_aguix,
                                         0,
                                         tty,
                                         catalog.getLocale( 8 ),
-                                        1,
-                                        0,
                                         0 ) );
 
     ba[0] = okb;
@@ -869,7 +853,7 @@ int ChModOwnCore::requestNewOwner( const FileEntry &fe, uid_t *return_owner, gid
 
         row = lvu->getActiveRow();
         if ( lvu->isValidRow( row ) == true ) {
-            elem = (chownrequest_id_name_t*)m_chown_user_list->getElementAt( lvu->getData( row ) );
+            elem = (chownrequest_id_name_t*)m_chown_user_list->getElementAt( lvu->getData( row, 0 ) );
             if ( elem != NULL ) {
                 if ( return_owner != NULL )
                     *return_owner = elem->id.uid;
@@ -878,7 +862,7 @@ int ChModOwnCore::requestNewOwner( const FileEntry &fe, uid_t *return_owner, gid
 
         row = lvg->getActiveRow();
         if ( lvg->isValidRow( row ) == true ) {
-            elem = (chownrequest_id_name_t*)m_chown_group_list->getElementAt( lvg->getData( row ) );
+            elem = (chownrequest_id_name_t*)m_chown_group_list->getElementAt( lvg->getData( row, 0 ) );
             if ( elem != NULL ) {
                 if ( return_group != NULL )
                     *return_group = elem->id.gid;
