@@ -78,7 +78,7 @@ ClipboardOp::run( WPUContext *wpu, ActionMessage *msg )
     if ( wpu->parse( m_string.c_str(),
                      res_str,
                      a_max( EXE_STRING_LEN - 1024, 256 ),
-                     false ) == WPUContext::PARSE_SUCCESS ) {
+                     false, WPUContext::PERSIST_FLAGS ) == WPUContext::PARSE_SUCCESS ) {
         msg->getWorker()->copyToClipboard( res_str );
     }
 
