@@ -111,6 +111,7 @@ struct mytoken tokenlist[]={
   {LEFTFONT_WCP,"leftfont"},
   {RIGHTFONT_WCP,"rightfont"},
   {TEXTVIEWFONT_WCP,"textviewfont"},
+  {STATEBARFONT_WCP,"statebarfont"},
   {CLOCKBARSETS_WCP,"clockbarsets"},
   {MODUS_WCP,"modus"},
   {TIMESPACE_WCP,"timespace"},
@@ -433,7 +434,10 @@ struct mytoken tokenlist[]={
   { USE_STRING_COMPARE_MODE_WCP, "usestringcomparemode" },
   { STRCASECMP_WCP, "strcasecmp" },
   { VIEWNEWESTFILESOP_WCP, "viewnewestfilesop" },
-  { SHOWRECENT_WCP, "showrecent" }
+  { SHOWRECENT_WCP, "showrecent" },
+  { DIRCOMPAREOP_WCP, "dircompareop" },
+  { TABPROFILESOP_WCP, "tabprofilesop" },
+  { EXTERNALVDIROP_WCP, "externalvdirop" },
 };
 
 ArrayList *tokenlist_sorted = NULL;
