@@ -712,7 +712,13 @@ CopyCore::copydir( const FileEntry *fe, NM_CopyOp_Dir *cod, bool acceptrename, c
                         // we need to do as failed rename
                         failedmove=true;
                     } else {
-                        if ( worker_rename( fe->fullname, destsubdir ) == 0 ) {
+                        if ( m_copyorder->adjust_relative_symlinks != m_copyorder->COPY_ADJUST_SYMLINK_NEVER ) {
+                            // skip trying to rename dir so that we can handle symlinks within the dir
+
+                            // assume that rename has failed so the source
+                            // dir is removed if copying was successful
+                            failedmove = true;
+                        } else if ( worker_rename( fe->fullname, destsubdir ) == 0 ) {
                             // success
                             docopy=false;
                         } else {
@@ -979,7 +985,14 @@ CopyCore::copyfile( const FileEntry *fe, bool acceptrename, const char *destdir,
                     if ( cowin != NULL ) cowin->newfile( fe->name, newfullname );
           
                     if(m_copyorder->move==true) {
-                        if ( worker_rename( fe->fullname, newfullname ) == 0 ) {
+                        if ( fe->isLink == true &&
+                             m_copyorder->adjust_relative_symlinks != m_copyorder->COPY_ADJUST_SYMLINK_NEVER ) {
+                            // skip trying to rename file for symlinks that possibly need to be adjusted
+
+                            // assume that rename has failed so the source
+                            // file is removed if copying was successful
+                            failedmove = true;
+                        } else if ( worker_rename( fe->fullname, newfullname ) == 0 ) {
                             // success
                             docopy=false;
                         } else {
