@@ -1,6 +1,6 @@
 /* copyop.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2006,2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2015 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -24,6 +24,7 @@
 
 #include "wdefines.h"
 #include "functionproto.h"
+#include "copy_parameters.hh"
 
 class CopyOp:public FunctionProto
 {
@@ -53,6 +54,14 @@ public:
   void setRequestFlags(bool);
   void setOverwrite(overwrite_t);
   void setPreserveAttr(bool);
+
+  typedef enum { COPYOP_ADJUST_SYMLINK_NEVER,
+                 COPYOP_ADJUST_SYMLINK_OUTSIDE,
+                 COPYOP_ADJUST_SYMLINK_ALWAYS
+  } adjust_relative_symlinks_t;
+
+  void setAdjustRelativeSymlinks( adjust_relative_symlinks_t nv );
+  void setEnsureFilePermissions( const CopyParams::EnsureFilePermissions &nv );
 protected:
   static const char *name;
   // Infos to save
@@ -62,6 +71,8 @@ protected:
   bool same_dir;
   bool request_dest;
   bool preserve_attr;
+  adjust_relative_symlinks_t adjust_relative_symlinks;
+  CopyParams::EnsureFilePermissions ensure_file_permissions;
   bool request_flags;
 
   overwrite_t overwrite;
@@ -76,10 +87,13 @@ protected:
   bool tsame_dir;
   bool trequest_dest;
   bool tpreserve_attr;
+  adjust_relative_symlinks_t tadjust_relative_symlinks;
+  CopyParams::EnsureFilePermissions tensure_file_permissions;
   overwrite_t toverwrite;
 
   int normalmodecopy( ActionMessage *am );
-  int requestdest( const char *defaultstr, char **dest );
+  int requestdest( const char *defaultstr, char **dest,
+                   bool show_do_not_ask, bool &do_not_ask_return );
 };
 
 #endif
