@@ -1,6 +1,6 @@
 /* createsymlinkop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2004,2008,2011,2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -229,7 +229,7 @@ CreateSymlinkOp::doconfigure(int mode)
 
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(36))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(36));
-  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr, AWindow::AWINDOW_DIALOG );
+  win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe(tstr);
 
@@ -237,17 +237,17 @@ CreateSymlinkOp::doconfigure(int mode)
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
 
-  ac1->add( new Text( aguix, 0, 0, catalog.getLocaleCom( 36 ), 1 ), 0, 0, cincwnr );
+  ac1->add( new Text( aguix, 0, 0, catalog.getLocaleCom( 36 ) ), 0, 0, cincwnr );
 
   sdcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, ( same_dir == true ) ? 1 : 0,
-						    catalog.getLocale( 315 ), LABEL_RIGHT, 1, 0 ), 0, 1, cincwnr );
+						    catalog.getLocale( 315 ), LABEL_RIGHT, 0 ), 0, 1, cincwnr );
 
   gcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, ( local == true ) ? 1 : 0,
-						   catalog.getLocale( 533 ), LABEL_RIGHT, 1, 0 ), 0, 2, cincwnr );
+						   catalog.getLocale( 533 ), LABEL_RIGHT, 0 ), 0, 2, cincwnr );
 
   if(mode==0) {
     rfcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, ( requestflags == true ) ? 1 : 0,
-						      catalog.getLocale( 294 ), LABEL_RIGHT, 1, 0 ), 0, 3, cincwnr );
+						      catalog.getLocale( 294 ), LABEL_RIGHT, 0 ), 0, 3, cincwnr );
   }
 
   AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 4 );
@@ -258,15 +258,11 @@ CreateSymlinkOp::doconfigure(int mode)
                                                 0,
                                                 0,
                                                 catalog.getLocale( 11 ),
-                                                1,
-                                                0,
                                                 0 ), 0, 0, cfix );
   Button *cb = (Button*)ac1_1->add( new Button( aguix,
 						0,
 						0,
 						catalog.getLocale( 8 ),
-						1,
-						0,
 						0 ), 1, 0, cfix );
   
   okb->takeFocus();
