@@ -1,6 +1,6 @@
 /* cursorops.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2007,2009,2011 Ralf Hoffmann.
+ * Copyright (C) 2001-2007,2009,2011,2013 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -21,12 +21,12 @@
 
 #include "cursorops.h"
 #include "listermode.h"
-#include "normalmode.h"
 #include "worker.h"
 #include "wpucontext.h"
 #include "ownop.h"
 #include "fileentry.hh"
 #include "worker_locale.h"
+#include "virtualdirmode.hh"
 
 /******
  RowUp
@@ -62,18 +62,12 @@ RowUp *RowUp::duplicate() const
 int RowUp::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
-  NormalMode *nm1;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
       lm1=l1->getActiveMode();
       if(lm1!=NULL) {
-        if(lm1->isType("NormalMode")==true) {
-          nm1=(NormalMode*)lm1;
-          nm1->up();
-        } else {
-            lm1->runCommand( "up" );
-        }
+          lm1->runCommand( "up" );
       }
     }
   }
@@ -123,18 +117,12 @@ RowDown *RowDown::duplicate() const
 int RowDown::run( WPUContext *wpu, ActionMessage *msg)
 {
   ListerMode *lm1;
-  NormalMode *nm1;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
       lm1=l1->getActiveMode();
       if(lm1!=NULL) {
-        if(lm1->isType("NormalMode")==true) {
-          nm1=(NormalMode*)lm1;
-          nm1->down();
-        } else {
-            lm1->runCommand( "down" );
-        }
+          lm1->runCommand( "down" );
       }
     }
   }
@@ -184,18 +172,12 @@ FirstRow *FirstRow::duplicate() const
 int FirstRow::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
-  NormalMode *nm1;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
       lm1=l1->getActiveMode();
       if(lm1!=NULL) {
-        if(lm1->isType("NormalMode")==true) {
-          nm1=(NormalMode*)lm1;
-          nm1->top();
-        } else {
-            lm1->runCommand( "first" );
-        }
+          lm1->runCommand( "first" );
       }
     }
   }
@@ -245,18 +227,12 @@ LastRow *LastRow::duplicate() const
 int LastRow::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
-  NormalMode *nm1;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
       lm1=l1->getActiveMode();
       if(lm1!=NULL) {
-        if(lm1->isType("NormalMode")==true) {
-          nm1=(NormalMode*)lm1;
-          nm1->last();
-        } else {
-            lm1->runCommand( "last" );
-        }
+          lm1->runCommand( "last" );
       }
     }
   }
@@ -306,18 +282,12 @@ PageUp *PageUp::duplicate() const
 int PageUp::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
-  NormalMode *nm1;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
       lm1=l1->getActiveMode();
       if(lm1!=NULL) {
-        if(lm1->isType("NormalMode")==true) {
-          nm1=(NormalMode*)lm1;
-          nm1->pageup();
-        } else {
-            lm1->runCommand( "pageup" );
-        }
+          lm1->runCommand( "pageup" );
       }
     }
   }
@@ -367,18 +337,12 @@ PageDown *PageDown::duplicate() const
 int PageDown::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
-  NormalMode *nm1;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
       lm1=l1->getActiveMode();
       if(lm1!=NULL) {
-        if(lm1->isType("NormalMode")==true) {
-          nm1=(NormalMode*)lm1;
-          nm1->pagedown();
-        } else {
-            lm1->runCommand( "pagedown" );
-        }
+          lm1->runCommand( "pagedown" );
       }
     }
   }
@@ -428,16 +392,12 @@ SelectOp *SelectOp::duplicate() const
 int SelectOp::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
-  NormalMode *nm1;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
       lm1=l1->getActiveMode();
       if(lm1!=NULL) {
-        if(lm1->isType("NormalMode")==true) {
-          nm1=(NormalMode*)lm1;
-          nm1->select();
-        }
+          lm1->runCommand( "selectentry" );
       }
     }
   }
@@ -487,16 +447,12 @@ SelectAllOp *SelectAllOp::duplicate() const
 int SelectAllOp::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
-  NormalMode *nm1;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
       lm1=l1->getActiveMode();
       if(lm1!=NULL) {
-        if(lm1->isType("NormalMode")==true) {
-          nm1=(NormalMode*)lm1;
-          nm1->selectall();
-        }
+          lm1->runCommand( "selectall" );
       }
     }
   }
@@ -546,16 +502,12 @@ SelectNoneOp *SelectNoneOp::duplicate() const
 int SelectNoneOp::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
-  NormalMode *nm1;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
       lm1=l1->getActiveMode();
       if(lm1!=NULL) {
-        if(lm1->isType("NormalMode")==true) {
-          nm1=(NormalMode*)lm1;
-          nm1->selectnone();
-        }
+          lm1->runCommand( "selectnone" );
       }
     }
   }
@@ -605,16 +557,12 @@ InvertAllOp *InvertAllOp::duplicate() const
 int InvertAllOp::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
-  NormalMode *nm1;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
       lm1=l1->getActiveMode();
       if(lm1!=NULL) {
-        if(lm1->isType("NormalMode")==true) {
-          nm1=(NormalMode*)lm1;
-          nm1->invertall();
-        }
+          lm1->runCommand( "invertall" );
       }
     }
   }
@@ -664,20 +612,19 @@ ParentDirOp *ParentDirOp::duplicate() const
 int ParentDirOp::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
-  NormalMode *nm1;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
       lm1=l1->getActiveMode();
       if(lm1!=NULL) {
-        if(lm1->isType("NormalMode")==true) {
-          nm1=(NormalMode*)lm1;
-
-          if ( nm1->filteredSearchActive() == true ) {
-              nm1->deactivateFilteredSearch();
+        if ( auto vdm = dynamic_cast< VirtualDirMode * >( lm1 ) ) {
+          if ( vdm->filteredSearchActive() == true ) {
+              vdm->deactivateFilteredSearch();
           } else {
-              nm1->parent();
+              lm1->runCommand( "parentdir" );
           }
+        } else {
+            lm1->runCommand( "parentdir" );
         }
       }
     }
