@@ -1344,6 +1344,6 @@ bool Datei::lock()
 void Datei::unlock()
 {
 #ifdef HAVE_LOCKF
-    lockf( fd, F_ULOCK, 0 );
+    int res __attribute__((unused)) = lockf( fd, F_ULOCK, 0 );
 #endif
 }
