@@ -349,7 +349,7 @@ const std::string &DirFilterSettings::getSpecificBookmarkLabel() const
     return m_bookmark_label;
 }
 
-NM_Filter::check_t DirFilterSettings::checkFilter( const char *filter ) throw( int )
+NM_Filter::check_t DirFilterSettings::checkFilter( const char *filter )
 {
     std::list<NM_Filter>::iterator it;
     
