@@ -1,6 +1,6 @@
 /* dirsizeop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2004,2008,2011 Ralf Hoffmann.
+ * Copyright (C) 2001-2004,2008,2011,2013 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -21,10 +21,11 @@
 
 #include "dirsizeop.h"
 #include "listermode.h"
-#include "normalmode.h"
 #include "worker.h"
 #include "nmspecialsourceext.hh"
 #include "worker_locale.h"
+#include "dirsizeorder.hh"
+#include "virtualdirmode.hh"
 
 const char *DirSizeOp::name="DirSizeOp";
 
@@ -64,9 +65,13 @@ DirSizeOp::run( WPUContext *wpu, ActionMessage *msg )
     if(l1!=NULL) {
       startlister=l1;
       lm1=startlister->getActiveMode();
-      if(lm1!=NULL)
-        if(lm1->isType("NormalMode")==true)
-          normalmodedirsize( msg );
+      if(lm1!=NULL) {
+          if(dynamic_cast< VirtualDirMode * > ( lm1 ) ) {
+              normalmodedirsize( msg );
+          } else {
+            lm1->not_supported();
+          }
+      }
     }
   }
   return 0;
@@ -81,7 +86,6 @@ DirSizeOp::getDescription()
 int
 DirSizeOp::normalmodedirsize( ActionMessage *am )
 {
-  NormalMode *nm1=NULL;
   ListerMode *lm1=NULL;
   struct NM_dirsizeorder dsorder;
   NM_specialsourceExt *specialsource=NULL;
@@ -89,8 +93,6 @@ DirSizeOp::normalmodedirsize( ActionMessage *am )
   if(startlister==NULL) return 1;
   lm1=startlister->getActiveMode();
   if(lm1==NULL) return 1;
-  if(lm1->isType("NormalMode")!=true) return 1;
-  nm1=(NormalMode*)lm1;
   
   memset( &dsorder, 0, sizeof( dsorder ) );
   if(am->mode==am->AM_MODE_ONLYACTIVE)
@@ -110,7 +112,10 @@ DirSizeOp::normalmodedirsize( ActionMessage *am )
   } else
     dsorder.source=dsorder.NM_ALLENTRIES;
 
-  nm1->dirsize(&dsorder);
+  if ( auto vdm = dynamic_cast< VirtualDirMode * >( lm1 ) ) {
+      vdm->dirsize( &dsorder );
+  }
+
   if(dsorder.source==dsorder.NM_SPECIAL) {
     if ( specialsource != NULL ) delete specialsource;
     delete dsorder.sources;
