@@ -1,6 +1,6 @@
 /* dirsortsettings.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2007 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2007,2012-2013 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -21,6 +21,8 @@
 
 #include "dirsortsettings.hh"
 #include "verzeichnis.hh"
+#include "nwcentryselectionstate.hh"
+#include <algorithm>
 
 DirSortSettings::DirSortSettings() : _serial_nr( 0 ),
                                      _sort_mode( SORT_NAME )
@@ -37,6 +39,21 @@ bool DirSortSettings::check( Verzeichnis &v )
     return true;
 }
 
+bool DirSortSettings::check( std::vector< NWCEntrySelectionState > &d )
+{
+    std::sort( d.begin(),
+               d.end(),
+               [&]( const NWCEntrySelectionState &l,
+                   const NWCEntrySelectionState &r ) -> bool
+               {
+                   return ( NWCEntrySelectionState::sortfunction( l,
+                                                                  r,
+                                                                  _sort_mode ) < 0 ) ? true : false;
+               } );
+
+    return true;
+}
+
 void DirSortSettings::setSortMode( int sort_mode )
 {
     _sort_mode = sort_mode;
