@@ -1,6 +1,6 @@
 /* dmcacheentrynwc.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2012-2013 Ralf Hoffmann.
+ * Copyright (C) 2012-2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -28,7 +28,9 @@
 #include "stringcomparator.hh"
 #include "simplelist.hh"
 #include "wconfig.h"
+#include "wcfiletype.hh"
 #include <aguix/util.h>
+#include "commonprefix.hh"
 
 DMCacheEntryNWC::DMCacheEntryNWC( std::unique_ptr< NWC::Dir > dir,
                                   DirFilterSettings *dir_filter_sets,
@@ -65,7 +67,7 @@ void DMCacheEntryNWC::setDir( std::unique_ptr< NWC::Dir > dir )
     updateView( true );
 }
 
-void DMCacheEntryNWC::reload()
+void DMCacheEntryNWC::reload( int flags )
 {
     if ( ! m_dir.get() ) return;
 
@@ -91,7 +93,7 @@ void DMCacheEntryNWC::reload()
     sorter.check( m_entries );
     sorter.check( old_entries );
 
-    applyOldSettings( m_entries, old_entries, m_active_entry, old_active_entry );
+    applyOldSettings( m_entries, old_entries, m_active_entry, old_active_entry, flags );
 
     updateView( true );
 
@@ -123,7 +125,8 @@ void DMCacheEntryNWC::reload()
 void DMCacheEntryNWC::applyOldSettings( std::vector< NWCEntrySelectionState > &new_entries,
                                         std::vector< NWCEntrySelectionState > &old_entries,
                                         active_entry &new_active_entry,
-                                        active_entry &old_active_entry )
+                                        active_entry &old_active_entry,
+                                        int flags )
 {
     auto old_es_it = old_entries.begin();
 
@@ -146,7 +149,20 @@ void DMCacheEntryNWC::applyOldSettings( std::vector< NWCEntrySelectionState > &n
                     // same name -> apply values
 
                     new_es.setSelected( old_es_it->getSelected() );
-                    new_es.setFiletype( old_es_it->getFiletype() );
+
+                    if ( old_es_it->getFiletype() ) {
+                        if ( flags & RESET_FILETYPE_FOR_CHANGED_SIZE_OF_UNKNOWN ) {
+                            // only apply if size is still the same or
+                            // the file type is already known
+                            if ( new_fse->stat_size() == old_fse->stat_size() ||
+                                 old_es_it->getFiletype()->getinternID() != UNKNOWNTYPE ) {
+                                new_es.setFiletype( old_es_it->getFiletype() );
+                            }
+                        } else {
+                            // always apply
+                            new_es.setFiletype( old_es_it->getFiletype() );
+                        }
+                    }
                     new_es.setColor( old_es_it->getColor() );
                     new_es.setBookmarkInfo( old_es_it->getBookmarkInfo() );
 
@@ -329,6 +345,16 @@ loff_t DMCacheEntryNWC::getSizeOfDirs( bool selected ) const
     return m_files_dirs.dirs_bytes;
 }
 
+long DMCacheEntryNWC::getNrOfHiddenFiles() const
+{
+    return m_files_dirs.hidden_files;
+}
+
+long DMCacheEntryNWC::getNrOfHiddenDirs() const
+{
+    return m_files_dirs.hidden_dirs;
+}
+
 const std::string &DMCacheEntryNWC::getCommonPrefix()
 {
     if ( ! m_common_path_prefix.calculated ) {
@@ -340,60 +366,17 @@ const std::string &DMCacheEntryNWC::getCommonPrefix()
 
 void DMCacheEntryNWC::recalcCommonPrefix()
 {
-    std::vector< std::string > components;
-    bool first = true;
+    CommonPrefix cp;
 
     for ( const auto &es : m_entries ) {
         const NWC::FSEntry *fse = es.getNWCEntry();
 
         if ( !fse ) continue;
 
-        if ( first ) {
-            AGUIXUtils::split_string( components,
-                                      fse->getFullname(),
-                                      '/' );
-
-            // the basename should always be separate so reduce the size by one
-
-            if ( components.size() >= 1 ) {
-                components.resize( components.size() - 1 );
-            }
-
-            first = false;
-        } else {
-            std::vector< std::string > temp_components;
-            
-            AGUIXUtils::split_string( temp_components,
-                                      fse->getFullname(),
-                                      '/' );
-
-            // the basename should always be separate so reduce the size by one
-
-            if ( temp_components.size() >= 1 ) {
-                temp_components.resize( temp_components.size() - 1 );
-            }
-
-            size_t p = 0;
-
-            for ( ;; p++ ) {
-                if ( p >= components.size() ) break;
-                if ( p >= temp_components.size() ) break;
-
-                if ( components[p] != temp_components[p] ) break;
-            }
-
-            // p is the first position of a different path component
-            // therefore reduce size of vector
-            components.resize( p );
-        }
+        cp.updateCommonPrefix( fse->getFullname() );
     }
 
-    m_common_path_prefix.prefix_string = "";
-
-    for ( const auto &p : components ) {
-        m_common_path_prefix.prefix_string += p;
-        m_common_path_prefix.prefix_string += '/';
-    }
+    m_common_path_prefix.prefix_string = cp.getCommonPrefix();
 
     m_common_path_prefix.calculated = true;
 }
@@ -469,6 +452,12 @@ void DMCacheEntryNWC::changeEntryInStats( const NWCEntrySelectionState &es,
                 m_unchecked_entries += modifier;
             }
         }
+    } else if ( fse->getBasename() != ".." ) {
+        if ( fse->isDir( true ) ) {
+            m_files_dirs.hidden_dirs += 1 * modifier;
+        } else {
+            m_files_dirs.hidden_files += 1 * modifier;
+        }
     }
 }
 
@@ -685,7 +674,7 @@ int DMCacheEntryNWC::removeEntry( int pos )
     return 0;
 }
 
-int DMCacheEntryNWC::hideEntry( int pos )
+int DMCacheEntryNWC::temporarilyHideEntry( int pos )
 {
     if ( pos < 0 || pos >= (int)m_entries.size() ) return 1;
 
@@ -693,6 +682,9 @@ int DMCacheEntryNWC::hideEntry( int pos )
 
     m_entries[pos].setUse( false );
 
+    // the stats are not updated since the counters must be updated
+    // afterwards anyway
+
     return 0;
 }
 
