@@ -1,6 +1,6 @@
 /* fileviewerbg.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2010-2015 Ralf Hoffmann.
+ * Copyright (C) 2010-2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -35,22 +35,27 @@
 #include <aguix/stringgadget.h>
 #include "worker_locale.h"
 #include "wconfig.h"
+#include "listermode.h"
+#include "virtualdirmode.hh"
 
-FileViewerBG::FileViewerBG() : win( NULL ),
-                               m_wrap_mode( false ),
-                               m_showlinenumbers_mode( false ),
-                               ts( NULL ),
-                               tv( NULL ),
-                               search_sg( NULL ),
-                               okb( NULL ),
-                               wcb( NULL ),
-                               slncb( NULL ),
-                               jumplineb( NULL ),
-                               readmoreb( NULL ),
-                               m_next_match_b( NULL ),
-                               m_prev_match_b( NULL ),
-                               m_restart_search_b( NULL ),
-                               m_find_pos_text( NULL )
+FileViewerBG::FileViewerBG( Worker *worker ) : win( NULL ),
+                                               m_wrap_mode( false ),
+                                               m_showlinenumbers_mode( false ),
+                                               ts( NULL ),
+                                               tv( NULL ),
+                                               search_sg( NULL ),
+                                               okb( NULL ),
+                                               wcb( NULL ),
+                                               slncb( NULL ),
+                                               jumplineb( NULL ),
+                                               readmoreb( NULL ),
+                                               reloadb( NULL ),
+                                               m_next_match_b( NULL ),
+                                               m_prev_match_b( NULL ),
+                                               m_restart_search_b( NULL ),
+                                               m_showintab_b( NULL ),
+                                               m_find_pos_text( NULL ),
+                                               m_worker( worker )
 {
 }
 
@@ -95,7 +100,7 @@ void FileViewerBG::view( const std::list<std::string> &filelist,
     ac1->setMinSpace( 5 );
     ac1->setMaxSpace( 5 );
 
-    AContainer *ac1_1 = ac1->add( new AContainer( win, 3, 1 ), 0, 0 );
+    AContainer *ac1_1 = ac1->add( new AContainer( win, 4, 1 ), 0, 0 );
     ac1_1->setMinSpace( 5 );
     ac1_1->setMaxSpace( 5 );
     ac1_1->setBorderWidth( 0 );
@@ -105,6 +110,10 @@ void FileViewerBG::view( const std::list<std::string> &filelist,
                                      2, 0, cfix );
     readmoreb->setBubbleHelpText( catalog.getLocale( 1146 ) );
 
+    reloadb = ac1_1->addWidget( new Button( aguix, 0, 0, catalog.getLocale( 511 ), 0 ),
+                                3, 0, cfix );
+    reloadb->setBubbleHelpText( catalog.getLocale( 1175 ) );
+
     fnt->setTextShrinker( RefCount<TextShrinker>( new FileNameShrinker() ) );
 
     it1 = filelist.begin();
@@ -122,7 +131,7 @@ void FileViewerBG::view( const std::list<std::string> &filelist,
     ac1->readLimits();
     ac1_1->readLimits();
 
-    AContainer *ac1_3 = ac1->add( new AContainer( win, 4, 1 ), 0, 3 );
+    AContainer *ac1_3 = ac1->add( new AContainer( win, 6, 1 ), 0, 3 );
     ac1_3->setMinSpace( 5 );
     ac1_3->setMaxSpace( -1 );
     ac1_3->setBorderWidth( 0 );
@@ -141,12 +150,23 @@ void FileViewerBG::view( const std::list<std::string> &filelist,
                                                          LABEL_RIGHT, 0 ),
                                        1, 0, cincwnr );
     slncb->setBubbleHelpText( catalog.getLocale( 1148 ) );
+
+    snp_cb = ac1_3->addWidget( new ChooseButton( aguix, 0, 0,
+                                                 false, catalog.getLocale( 1176 ),
+                                                 LABEL_RIGHT, 0 ),
+                               2, 0, cincwnr );
+    snp_cb->setBubbleHelpText( catalog.getLocale( 1177 ) );
+
     jumplineb = (Button*)ac1_3->add( new Button( aguix, 0, 0, catalog.getLocale( 716 ), 2 ),
-                                     2, 0, cfix );
+                                     3, 0, cfix );
     jumplineb->setBubbleHelpText( catalog.getLocale( 1142 ) );
 
+    m_showintab_b = ac1_3->addWidget( new Button( aguix, 0, 0, catalog.getLocale( 1178 ), 2 ),
+                                      4, 0, cfix );
+    m_showintab_b->setBubbleHelpText( catalog.getLocale( 1179 ) );
+
     okb = (Button*)ac1_3->add( new Button( aguix, 0, 0, catalog.getLocale( 633 ), 2 ),
-                               3, 0, cfix );
+                               5, 0, cfix );
     okb->setBubbleHelpText( catalog.getLocale( 1143 ) );
 
     AContainer *ac1_4 = ac1->add( new AContainer( win, 5, 1 ), 0, 2 );
@@ -246,6 +266,13 @@ void FileViewerBG::handleAGUIXMessage( AGMessage &msg )
                 tv->setLineWrap( msg.choose.state );
             } else if ( msg.choose.button == slncb ) {
                 tv->setShowLineNumbers( msg.choose.state );
+            } else if ( msg.choose.button == snp_cb ) {
+                if ( msg.choose.state ) {
+                    ts->setConvertMode( TextStorageString::CONVERT_NON_PRINTABLE_HEX );
+                } else {
+                    ts->setConvertMode( TextStorageString::CONVERT_NON_PRINTABLE_SIMPLE );
+                }
+                tv->textStorageChanged();
             }
             break;
         case AG_BUTTONCLICKED:
@@ -268,12 +295,20 @@ void FileViewerBG::handleAGUIXMessage( AGMessage &msg )
                 if ( ts->incompleteFile() == false ) {
                     readmoreb->hide();
                 }
+            } else if ( msg.button.button == reloadb ) {
+                ts->reloadFile();
+                tv->textStorageChanged();
+                if ( ts->incompleteFile() == false ) {
+                    readmoreb->hide();
+                }
             } else if ( msg.button.button == m_next_match_b ) {
                 nextMatch();
             } else if ( msg.button.button == m_prev_match_b ) {
                 nextMatch( true );
             } else if ( msg.button.button == m_restart_search_b ) {
                 restartSearchFromTop();
+            } else if ( msg.button.button == m_showintab_b ) {
+                showInWorkerTab();
             }
             break;
             /*        case AG_KEYPRESSED:
@@ -302,12 +337,20 @@ void FileViewerBG::handleAGUIXMessage( AGMessage &msg )
                         }
                         break;
                     case XK_r:
-                        if ( ts->incompleteFile() == true ) {
-                            ts->readMore();
+                        if ( ( msg.key.keystate & ( ControlMask | Mod1Mask ) ) != 0 ) {
+                            ts->reloadFile();
                             tv->textStorageChanged();
                             if ( ts->incompleteFile() == false ) {
                                 readmoreb->hide();
                             }
+                        } else {
+                            if ( ts->incompleteFile() == true ) {
+                                ts->readMore();
+                                tv->textStorageChanged();
+                                if ( ts->incompleteFile() == false ) {
+                                    readmoreb->hide();
+                                }
+                            }
                         }
                         break;
                     case XK_slash:
@@ -470,7 +513,7 @@ int FileViewerBG::buildTextView( const std::string &filename,
     if ( ts != NULL ) {
         delete ts;
     }
-    ts = new TextStorageFile( filename, lencalc, initial_size );
+    ts = new TextStorageFile( filename, lencalc, initial_size, TextStorageString::CONVERT_NON_PRINTABLE_SIMPLE );
     tv = new TextView( aguix, 0, 0, 100, 100, "", *ts );
 
     ts_search = new SearchTextStorage( *ts );
@@ -565,3 +608,26 @@ void FileViewerBG::restartSearchFromTop()
     ts_search->setSearchStartLine( 0 );
     nextMatch();
 }
+
+void FileViewerBG::showInWorkerTab()
+{
+    if ( ! m_worker ) return;
+
+    auto it1 = m_filelist.begin();
+
+    if ( it1 == m_filelist.end() ) return;
+
+    Lister *l1;
+
+    l1 = m_worker->getActiveLister();
+    if ( l1 != NULL ) {
+        l1->switch2Mode( 0 );
+
+        VirtualDirMode *vdm = dynamic_cast< VirtualDirMode* >( l1->getActiveMode() );
+        if ( vdm != NULL ) {
+            vdm->newTab();
+
+            vdm->showDir( *it1 );
+        }
+    }
+}
