@@ -1,6 +1,6 @@
 /* fontreq.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2008,2011,2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -146,14 +146,14 @@ int FontRequester::request(const char *xname,char**return_xname)
   const int cmin = AContainer::ACONT_MINH +
                    AContainer::ACONT_MINW;
 
-  win = new AWindow( aguix, 10, 10, 10, 10, 0, catalog.getLocale( 204 ), AWindow::AWINDOW_DIALOG );
+  win = new AWindow( aguix, 10, 10, 10, 10, catalog.getLocale( 204 ), AWindow::AWINDOW_DIALOG );
   win->create();
 
   ac1 = win->setContainer( new AContainer( win, 1, 7 ), true );
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
 
-  ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 380 ), 1 ), 0, 0, cincwnr );
+  ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 380 ) ), 0, 0, cincwnr );
 
   AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 1 );
   ac1_1->setMinSpace( 5 );
@@ -180,8 +180,8 @@ int FontRequester::request(const char *xname,char**return_xname)
   ac1_2->setMaxSpace( 5 );
   ac1_2->setBorderWidth( 0 );
 
-  ac1_2->add( new Text( aguix, 0, 0, catalog.getLocale( 383 ), 1 ), 0, 0, cfix );
-  ftext = (Text*)ac1_2->add( new Text( aguix, 0, 0, "", 1 ), 1, 0, cincwnr );
+  ac1_2->add( new Text( aguix, 0, 0, catalog.getLocale( 383 ) ), 0, 0, cfix );
+  ftext = (Text*)ac1_2->add( new Text( aguix, 0, 0, "" ), 1, 0, cincwnr );
 
 #ifndef HAVE_XFT
   AContainer *ac1_4 = ac1->add( new AContainer( win, 4, 1 ), 0, 4 );
@@ -189,16 +189,16 @@ int FontRequester::request(const char *xname,char**return_xname)
   ac1_4->setMaxSpace( 5 );
   ac1_4->setBorderWidth( 0 );
 
-  ac1_4->add( new Text( aguix, 0, 0, catalog.getLocale( 713 ), 1 ), 0, 0, cfix );
-  missingtext = (Text*)ac1_4->add( new Text( aguix, 0, 0, "     ", 1 ), 1, 0, cincwnr );
-  Button *missing_help_b = (Button*)ac1_4->add( new Button( aguix, 0, 0, catalog.getLocale( 483 ), 1, 0, 0 ),
+  ac1_4->add( new Text( aguix, 0, 0, catalog.getLocale( 713 ) ), 0, 0, cfix );
+  missingtext = (Text*)ac1_4->add( new Text( aguix, 0, 0, "     " ), 1, 0, cincwnr );
+  Button *missing_help_b = (Button*)ac1_4->add( new Button( aguix, 0, 0, catalog.getLocale( 483 ), 0 ),
                                                 3, 0, cfix );
 #else
   ac1->setMinHeight( 0, 0, 4 );
   ac1->setMaxHeight( 0, 0, 4 );
 #endif
 
-  xb = (Button*)ac1->add( new Button( aguix, 0, 0, catalog.getLocale( 381 ), 1, 0, 0 ), 0, 5, cincw );
+  xb = (Button*)ac1->add( new Button( aguix, 0, 0, catalog.getLocale( 381 ), 0 ), 0, 5, cincw );
 
   AContainer *ac1_3 = ac1->add( new AContainer( win, 2, 1 ), 0, 6 );
   ac1_3->setMinSpace( 5 );
@@ -208,15 +208,11 @@ int FontRequester::request(const char *xname,char**return_xname)
 					0,
 					0,
 					catalog.getLocale( 11 ),
-					1,
-					0,
 					0 ), 0, 0, cfix );
   cb = (Button*)ac1_3->add( new Button( aguix,
 					0,
 					0,
 					catalog.getLocale( 8 ),
-					1,
-					0,
 					0 ), 1, 0, cfix );
   
   lv->setHBarState(2);
