@@ -110,6 +110,8 @@ public:
   static std::string getCategoryName( command_categories_t category );
 
   virtual command_categories_t getCategory() const;
+
+    virtual std::string getStringRepresentation();
 protected:
   static const char *name;
   bool hasConfigure;
@@ -118,6 +120,8 @@ protected:
 
 void freecoms(List*);
 
+std::string getStringReprForList( List *coms );
+
 #endif
 
 /* Local Variables: */
