@@ -157,7 +157,7 @@ InternalViewOp::run( WPUContext *wpu, ActionMessage *msg )
             msg->getWorker()->storePathPersIfInProgress( f );
         }
 
-        FileViewer fv;
+        FileViewer fv( msg->getWorker() );
         fv.view( filelist, NULL );
     }
   }
