@@ -51,6 +51,9 @@ Lister::Lister(Worker *tparent)
                               0, 0, AContainer::CO_INCW );
   m_cont->setMinWidth( 50, 0, 0 );
   lvb->setAcceptFocus( false );
+
+  lvb->setBubbleHelpText( catalog.getLocale( 1124 ) );
+  
   aguix->Flush();
   activemode=NULL;
   activemodeid=-1;
@@ -227,7 +230,7 @@ bool Lister::isActive()
 void Lister::configure()
 {
   int nr,j,i;
-  AWindow *win2 = new AWindow( aguix, 10, 10, 10, 10, 0, catalog.getLocale( 16 ), AWindow::AWINDOW_DIALOG );
+  AWindow *win2 = new AWindow( aguix, 10, 10, 10, 10, catalog.getLocale( 16 ), AWindow::AWINDOW_DIALOG );
   const int cincw = AContainer::ACONT_MINH +
                     AContainer::ACONT_MINW +
                     AContainer::ACONT_MAXH;
@@ -244,7 +247,7 @@ void Lister::configure()
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
 
-  ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 166 ), 1 ), 0, 0, cincwnr );
+  ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 166 ) ), 0, 0, cincwnr );
 
   nr = parent->getMaxModeNr();
 
@@ -279,22 +282,16 @@ void Lister::configure()
                                                 0,
                                                 0,
                                                 catalog.getLocale( 997 ),
-                                                1,
-                                                0,
                                                 0 ), 0, 0, cfix );
   auto configb = (Button*)ac1_2->add( new Button( aguix,
                                                   0,
                                                   0,
                                                   catalog.getLocale( 998 ),
-                                                  1,
-                                                  0,
                                                   0 ), 1, 0, cfix );
   Button *cancelb = (Button*)ac1_2->add( new Button( aguix,
 						     0,
 						     0,
 						     catalog.getLocale( 633 ),
-						     1,
-						     0,
 						     0 ), 2, 0, cfix );
 
   okb->takeFocus();
@@ -618,3 +615,13 @@ void Lister::finalizeBGOps()
         modes[i]->finalizeBGOps();
     }
 }
+
+void Lister::setLastPath( const std::string &path )
+{
+    m_last_path = path;
+}
+
+std::string Lister::getLastPath() const
+{
+    return m_last_path;
+}
