@@ -86,7 +86,8 @@ public:
 
     virtual std::string getCurrentDirectory();
 
-    virtual bool deselectEntry( const std::string &filename );
+    virtual bool setEntrySelectionState( const std::string &filename,
+                                         bool state );
 
     virtual void updateOnBookmarkChange();
 
