@@ -1,6 +1,6 @@
 /* menutreeui.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2013-2014 Ralf Hoffmann.
+ * Copyright (C) 2013-2014,2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -30,6 +30,7 @@
 #include <aguix/stringgadget.h>
 #include <aguix/textview.h>
 #include <aguix/utf8.hh>
+#include <aguix/choosebutton.h>
 #include <algorithm>
 #include <iostream>
 #include "prefixdb.hh"
@@ -40,16 +41,21 @@
 MenuTreeUI::MenuTreeUI( AGUIX *aguix )
     : m_aguix( aguix ),
       m_menu( NULL ),
-      m_current_dehighlight_entry( NULL )
+      m_current_dehighlight_entry( NULL ),
+      m_show_recently_used( false )
 {
     std::string cfgfile = Worker::getWorkerConfigDir();
+    std::string recently_used_file;
 #ifdef USEOWNCONFIGFILES
+    recently_used_file = NWC::Path::join( cfgfile, "menu-recent2" );
     cfgfile = NWC::Path::join( cfgfile, "menu-choices2" );
 #else
+    recently_used_file = NWC::Path::join( cfgfile, "menu-recent" );
     cfgfile = NWC::Path::join( cfgfile, "menu-choices" );
 #endif
 
     m_pdb = std::unique_ptr< PrefixDB >( new PrefixDB( cfgfile ) );
+    m_recently_used = std::make_shared< PersistentStringList >( recently_used_file );
 }
 
 MenuTreeUI::~MenuTreeUI()
@@ -63,7 +69,7 @@ void MenuTreeUI::setMenuTree( MenuTree *menu )
     m_menu = menu;
 }
 
-void MenuTreeUI::show()
+void MenuTreeUI::show( bool show_recently_used )
 {
     const AWindow *twin = NULL;
 
@@ -78,7 +84,7 @@ void MenuTreeUI::show()
         mainwin->setTransientForAWindow( twin );
     }
 
-    AContainer *maincont = mainwin->setContainer( new AContainer( mainwin, 1, 5 ), true );
+    AContainer *maincont = mainwin->setContainer( new AContainer( mainwin, 1, 6 ), true );
 
     maincont->setMinSpace( 5 );
     maincont->setMaxSpace( 5 );
@@ -101,8 +107,14 @@ void MenuTreeUI::show()
     tv_cd.setTextColor( 1 );
     help_tv->setColors( tv_cd );
 
+    ChooseButton *recently_cb = maincont->addWidget( new ChooseButton( m_aguix,
+                                                                       0, 0,
+                                                                       show_recently_used,
+                                                                       catalog.getLocale( 1170 ), LABEL_LEFT, 0 ),
+                                                     0, 1, AContainer::CO_INCWNR );
+
     AContainer *subcont0 = maincont->add( new AContainer( mainwin, 2, 1 ),
-                                          0, 1 );
+                                          0, 2 );
     subcont0->setMinSpace( 5 );
     subcont0->setMaxSpace( 5 );
     subcont0->setBorderWidth( 0 );
@@ -113,7 +125,7 @@ void MenuTreeUI::show()
                                          1, 0, AContainer::CO_INCW );
 
     AContainer *subcont1 = maincont->add( new AContainer( mainwin, 3, 2 ),
-                                          0, 3 );
+                                          0, 4 );
     subcont1->setMinSpace( 5 );
     subcont1->setMaxSpace( 5 );
     subcont1->setBorderWidth( 0 );
@@ -146,7 +158,7 @@ void MenuTreeUI::show()
     m_lv_key->setVBarState( 2 );
 
     AContainer *subcont3 = maincont->add( new AContainer( mainwin, 2, 1 ),
-                                          0, 2 );
+                                          0, 3 );
     subcont3->setMinSpace( 5 );
     subcont3->setMaxSpace( 5 );
     subcont3->setBorderWidth( 0 );
@@ -157,7 +169,7 @@ void MenuTreeUI::show()
                                                        "" ),
                                          1, 0, AContainer::CO_INCW );
 
-    AContainer *subcont2 = maincont->add( new AContainer( mainwin, 2, 1 ), 0, 4 );
+    AContainer *subcont2 = maincont->add( new AContainer( mainwin, 2, 1 ), 0, 5 );
     subcont2->setMinSpace( 5 );
     subcont2->setMaxSpace( -1 );
     subcont2->setBorderWidth( 0 );
@@ -195,8 +207,16 @@ void MenuTreeUI::show()
     MenuTreeNode *root = m_menu->getRootNode();
     m_menu->setCurrentNode( root );
 
-    m_menu->setFilter( "" );
+    m_show_recently_used = show_recently_used;
+
+    if ( show_recently_used ) {
+        m_menu->setVisibleList( m_recently_used );
+    } else {
+        m_menu->setVisibleList( NULL );
+    }
     
+    m_menu->setFilter( "" );
+
     showMenu();
 
     std::string current_filter;
@@ -352,6 +372,23 @@ void MenuTreeUI::show()
                         }
                     } else if ( agmsg->key.key == XK_Escape ) {
                         end_mode = -1;
+                    } else if ( agmsg->key.key == XK_r &&
+                                KEYSTATEMASK( agmsg->key.keystate ) == ControlMask ) {
+                        if ( recently_cb->getState() ) {
+                            m_menu->setVisibleList( NULL );
+                            recently_cb->setState( false );
+                            m_show_recently_used = false;
+                        } else {
+                            m_menu->setVisibleList( m_recently_used );
+                            recently_cb->setState( true );
+                            m_show_recently_used = true;
+                        }
+
+                        m_menu->setFilter( filtertext->getText() );
+
+                        showMenu();
+
+                        updateBreadcrumb();
                     } else if ( IsModifierKey( agmsg->key.key ) ||
                                 IsCursorKey( agmsg->key.key ) ||
                                 IsPFKey( agmsg->key.key ) ||
@@ -419,6 +456,23 @@ void MenuTreeUI::show()
                 case AG_FIELDLV_HSCROLL:
                     syncHelpLV( agmsg->fieldlv.lv );
                     break;
+                case AG_CHOOSECLICKED:
+                    if ( agmsg->choose.button == recently_cb ) {
+                        if ( agmsg->choose.state == true ) {
+                            m_menu->setVisibleList( m_recently_used );
+                            m_show_recently_used = true;
+                        } else {
+                            m_menu->setVisibleList( NULL );
+                            m_show_recently_used = false;
+                        }
+
+                        m_menu->setFilter( filtertext->getText() );
+
+                        showMenu();
+
+                        updateBreadcrumb();
+                    }
+                    break;
             }
 
             m_aguix->ReplyMessage( agmsg );
@@ -440,14 +494,17 @@ void MenuTreeUI::show()
 
         int row = m_lv->getActiveRow();
 
-        if ( ! current_filter.empty() ) {
+        if ( m_lv->isValidRow( row ) ) {
+            std::string fullname = prefix;
+            if ( ! fullname.empty() ) {
+                fullname += "/";
+            }
+            fullname += m_lv->getText( row, 0 );
 
-            if ( m_lv->isValidRow( row ) ) {
-                std::string fullname = prefix;
-                if ( ! fullname.empty() ) {
-                    fullname += "/";
-                }
-                fullname += m_lv->getText( row, 0 );
+            m_recently_used->removeEntry( fullname );
+            m_recently_used->pushFrontEntry( fullname );
+
+            if ( ! current_filter.empty() ) {
 
                 fullname += ";";
 
@@ -460,15 +517,15 @@ void MenuTreeUI::show()
                 m_pdb->pushAccess( filter,
                                    fullname );
             }
-        }
 
-        int pos = 0;
-        for ( const auto &it : m_current_entries ) {
-            if ( pos == row ) {
-                activate_element = it.second;
-                break;
+            int pos = 0;
+            for ( const auto &it : m_current_entries ) {
+                if ( pos == row ) {
+                    activate_element = std::get< 1 >( it );
+                    break;
+                }
+                pos++;
             }
-            pos++;
         }
     }
 
@@ -497,6 +554,30 @@ void MenuTreeUI::showMenu()
 
     m_menu->fillFullname( m_current_entries );
 
+    if ( m_show_recently_used ) {
+        m_current_entries.sort( []( const std::pair< std::string, MenuTreeNode * > &lhs,
+                                    const std::pair< std::string, MenuTreeNode * > &rhs ) -> bool {
+                                    int lhs_pos = lhs.second->getVisiblePos();
+                                    int rhs_pos = rhs.second->getVisiblePos();
+
+                                    if ( lhs_pos == rhs_pos ) {
+                                        return lhs.second->getName() < rhs.second->getName ();
+                                    }
+
+                                    // put negative pos (not in visible list) last, should actually not happen
+
+                                    if ( lhs_pos < 0 && rhs_pos >= 0 ) {
+                                        return false;
+                                    }
+
+                                    if ( lhs_pos >= 0 && rhs_pos < 0 ) {
+                                        return true;
+                                    }
+
+                                    return lhs_pos < rhs_pos;
+                                } );
+    }
+    
     for ( const auto it1 : m_current_entries ) {
         int row1 = m_lv->addRow();
         m_lv_help->addRow();
@@ -506,11 +587,11 @@ void MenuTreeUI::showMenu()
         m_lv_help->setPreColors( row1, FieldListView::PRECOLOR_ONLYACTIVE );
         m_lv_key->setPreColors( row1, FieldListView::PRECOLOR_ONLYACTIVE );
 
-        m_lv->setText( row1, 0, it1.first );
-        m_lv_help->setText( row1, 0, it1.second->getHelp() );
-        m_lv_key->setText( row1, 0, it1.second->getKey() );
+        m_lv->setText( row1, 0, std::get< 0 >( it1 ) );
+        m_lv_help->setText( row1, 0, std::get< 1 >( it1 )->getHelp() );
+        m_lv_key->setText( row1, 0, std::get< 1 >( it1 )->getKey() );
 
-        if ( it1.first == old_entry ) {
+        if ( std::get< 0 >( it1 ) == old_entry ) {
             m_lv->setActiveRow( row1 );
         }
     }
@@ -541,7 +622,7 @@ void MenuTreeUI::highlightEntry( const MenuTreeNode *entry )
 
     for ( const auto it1 : m_current_entries ) {
 
-        if ( it1.second == entry ) {
+        if ( std::get< 1 >( it1 ) == entry ) {
             m_lv->setActiveRow( row );
             break;
         }
@@ -650,7 +731,7 @@ void MenuTreeUI::triggerEntryHighlightFunction( int row )
     int pos = 0;
     for ( const auto &it : m_current_entries ) {
         if ( pos == row ) {
-            triggerEntryHighlightFunction( it.second );
+            triggerEntryHighlightFunction( std::get< 1 >( it ) );
             break;
         }
         pos++;
