@@ -1,6 +1,6 @@
 /* modifytabsop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2009,2011,2013 Ralf Hoffmann.
+ * Copyright (C) 2009-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -154,7 +154,7 @@ ModifyTabsOp::configure()
     tstr = (char*)_allocsafe( strlen( catalog.getLocale( 293 ) ) +
                               strlen( catalog.getLocaleCom( 56 ) ) + 1 );
     sprintf( tstr, catalog.getLocale( 293 ), catalog.getLocaleCom( 56 ) );
-    win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr, AWindow::AWINDOW_DIALOG );
+    win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
     win->create();
     _freesafe(tstr);
     
@@ -167,8 +167,8 @@ ModifyTabsOp::configure()
     ac1_1->setMaxSpace( 5 );
     ac1_1->setBorderWidth( 0 );
     
-    ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 851 ), 1 ), 0, 0, AContainer::CO_FIX );
-    rcyb = (CycleButton*)ac1_1->add( new CycleButton( aguix, 0, 0, 100, 1, 0, 0 ), 1, 0, AContainer::CO_INCWNR );
+    ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 851 ) ), 0, 0, AContainer::CO_FIX );
+    rcyb = (CycleButton*)ac1_1->add( new CycleButton( aguix, 0, 0, 100, 0 ), 1, 0, AContainer::CO_INCWNR );
     rcyb->addOption( catalog.getLocale( 852 ) );
     rcyb->addOption( catalog.getLocale( 853 ) );
     rcyb->addOption( catalog.getLocale( 854 ) );
@@ -198,15 +198,11 @@ ModifyTabsOp::configure()
                                                   0,
                                                   0,
                                                   catalog.getLocale( 11 ),
-                                                  1,
-                                                  0,
                                                   0 ), 0, 0, AContainer::CO_FIX );
     Button *cb = (Button*)ac1_2->add( new Button( aguix,
                                                   0,
                                                   0,
                                                   catalog.getLocale( 8 ),
-                                                  1,
-                                                  0,
                                                   0 ), 1, 0, AContainer::CO_FIX );
     
     win->setDoTabCycling( true );
