@@ -1,6 +1,6 @@
 /* normalops.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2014 Ralf Hoffmann.
+ * Copyright (C) 2001-2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -684,6 +684,22 @@ void FilterSelectOp::closeHistory()
     m_history.reset();
 }
 
+std::list< std::string > FilterSelectOp::getHistory()
+{
+    if ( m_history ) {
+        return m_history->getList();
+    }
+
+    std::string str1;
+
+    str1 = WorkerInitialSettings::getInstance().getConfigBaseDir();
+    str1 = NWC::Path::join( str1, "filterselect-history" );
+
+    auto h = std::unique_ptr< PersistentStringList >( new PersistentStringList( str1 ) );
+
+    return h->getList();
+}
+
 void FilterSelectOp::addHistoryItem( const std::string &str )
 {
     if ( str.empty() ) return;
