@@ -1,6 +1,6 @@
 /* nwc_fsentry.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2006-2014 Ralf Hoffmann.
+ * Copyright (C) 2006-2014,2016 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -24,6 +24,8 @@
 #include <aguix/util.h>
 #include <string.h>  //memcpy
 #include "nwc_path.hh"
+#include "nwc_os.hh"
+#include "aguix/lowlevelfunc.h"
 
 namespace NWC
 {
@@ -387,38 +389,22 @@ namespace NWC
         return true;
     }
 
-    int FSEntry::writeDestination2Buf( char *buf, int len, bool null_terminated ) const
-    {
-        int x = -1;
-
-        if ( isLink() ) {
-            x = worker_readlink( _fullname.c_str(), buf, len - 1 );
-            if ( null_terminated == true && x >= 0 ) {
-                buf[x] = 0;
-            }
-        }
-        return x;
-    }
-
     bool FSEntry::getDestination( std::string &res ) const
     {
-        char buf[MAXPATHLEN];
+        char *buf;
 
         if ( ! isLink() ) return false;
 
-        int e = writeDestination2Buf( buf, MAXPATHLEN, true );
+        buf = NWC::OS::getLinkTarget( _fullname.c_str() );
 
-        if ( e >= MAXPATHLEN ) {
-            buf[MAXPATHLEN - 1] = '\0';
-        } else if ( e < 0 ) {
-            buf[0] = '\0';
-        } else {
-            buf[e] = '\0';
+        if ( buf ) {
+            res += buf;
+            _freesafe( buf );
+
+            return true;
         }
 
-        res += buf;
-
-        return true;
+        return false;
     }
 
     int FSEntry::changeBasename( const std::string &newbasename )
