@@ -331,7 +331,7 @@ void NWCEntrySelectionState::clearMatchingLabels()
     }
 }
 
-const std::list<std::string> &NWCEntrySelectionState::getMatchingLabels() const throw( int )
+const std::list<std::string> &NWCEntrySelectionState::getMatchingLabels() const
 {
     if ( ! m_bookmark_info.get() ) {
         throw 1;
@@ -382,7 +382,7 @@ void NWCEntrySelectionState::setCustomColors( const int fg[4], const int bg[4] )
     m_colors.setCustomColors( fg, bg );
 }
 
-const FileEntryCustomColor &NWCEntrySelectionState::getCustomColor() const throw ( int )
+const FileEntryCustomColor &NWCEntrySelectionState::getCustomColor() const
 {
     return m_colors.getCustomColor();
 }
