@@ -1,6 +1,6 @@
 /* pathjumpui.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2012-2015 Ralf Hoffmann.
+ * Copyright (C) 2012-2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -35,7 +35,6 @@
 #include <algorithm>
 #include "worker.h"
 #include "deeppathstore.hh"
-#include "stringmatcher_fnmatch.hh"
 #include "bookmarkdbproxy.hh"
 #include "persdeeppathstore.hh"
 #include "prefixdb.hh"
@@ -350,7 +349,13 @@ int PathJumpUI::mainLoop()
 {
     m_lv_dirty = true;
 
-    apply_filter( m_filter );
+    apply_filter( m_filter, NULL );
+
+    // do run2completion for the first call to have everything
+    // initialized
+    while ( ! m_apply_state.done ) {
+        apply_filter_next();
+    }
 
     highlight_best_hit( m_dirname );
 
@@ -374,7 +379,11 @@ int PathJumpUI::mainLoop()
     int endmode = 0;
 
     for ( ; endmode == 0; ) {
-        msg = m_aguix.WaitMessage( NULL );
+        if ( m_apply_state.done ) {
+            msg = m_aguix.WaitMessage( NULL );
+        } else {
+            msg = m_aguix.GetMessage( NULL );
+        }
         if ( msg != NULL ) {
             switch ( msg->type ) {
               case AG_CLOSEWINDOW:
@@ -395,27 +404,31 @@ int PathJumpUI::mainLoop()
                   } else if ( msg->button.button == m_plus1h_b ) {
                       m_entry_filter_age += 1 * 60 * 60;
 
-                      apply_filter( m_filter );
-                      showData();
-                      updateAgeText();
+                      apply_filter( m_filter, [this]( int matches ) {
+                              showData();
+                              updateAgeText();
+                          });
                   } else if ( msg->button.button == m_plus1d_b ) {
                       m_entry_filter_age += 1 * 24 * 60 * 60;
 
-                      apply_filter( m_filter );
-                      showData();
-                      updateAgeText();
+                      apply_filter( m_filter, [this]( int matches ) {
+                              showData();
+                              updateAgeText();
+                          });
                   } else if ( msg->button.button == m_plus1w_b ) {
                       m_entry_filter_age += 7 * 24 * 60 * 60;
 
-                      apply_filter( m_filter );
-                      showData();
-                      updateAgeText();
+                      apply_filter( m_filter, [this]( int matches ) {
+                              showData();
+                              updateAgeText();
+                          });
                   } else if ( msg->button.button == m_age_reset_b ) {
                       m_entry_filter_age = 0;
 
-                      apply_filter( m_filter );
-                      showData();
-                      updateAgeText();
+                      apply_filter( m_filter, [this]( int matches ) {
+                              showData();
+                              updateAgeText();
+                          });
                   } else if ( msg->button.button == m_hold_status_b ) {
                       if ( m_hold_status.active ) {
                           resetHeldEntriesAndUpdateUI();
@@ -435,16 +448,18 @@ int PathJumpUI::mainLoop()
                   if ( msg->key.key == XK_BackSpace ) {
                       if ( KEYSTATEMASK( msg->key.keystate ) == ShiftMask ) {
                           m_filter = "";
-                          apply_filter( m_filter );
-                          showData();
+                          apply_filter( m_filter, [this]( int matches ) {
+                                  showData();
+                              });
                       } else {
                           std::string cur_infix = m_filter;
                           
                           if ( cur_infix.length() > 0 ) {
                               cur_infix.resize( cur_infix.length() - 1 );
                               m_filter = cur_infix;
-                              apply_filter( m_filter );
-                              showData();
+                              apply_filter( m_filter, [this]( int matches ) {
+                                      showData();
+                                  });
                           }
                       }
                   } else if ( msg->key.key == XK_Return ) {
@@ -473,10 +488,14 @@ int PathJumpUI::mainLoop()
                       }
                   } else if ( msg->key.key == XK_Right ) {
                       if ( ! m_current_components.empty() ) {
-                          if ( m_current_depth < 0 ) {
-                              m_current_depth = 0;
-                          } else if ( m_current_depth <= (int)( m_current_components.size() - 1 ) ) {
-                              m_current_depth++;
+                          if ( KEYSTATEMASK( msg->key.keystate ) == ShiftMask ) {
+                              m_current_depth = (int)( m_current_components.size() );
+                          } else {
+                              if ( m_current_depth < 0 ) {
+                                  m_current_depth = 0;
+                              } else if ( m_current_depth <= (int)( m_current_components.size() - 1 ) ) {
+                                  m_current_depth++;
+                              }
                           }
 
                           if ( m_entry_filter_mode != SHOW_ALL ) {
@@ -523,15 +542,17 @@ int PathJumpUI::mainLoop()
                           if ( ! m_hold_status.active ) {
                               m_show_hidden_entries = ! m_show_hidden_entries;
                               m_show_all_cb->setState( m_show_hidden_entries );
-                              apply_filter( m_filter );
-                              showData();
+                              apply_filter( m_filter, [this]( int matches ) {
+                                      showData();
+                                  });
                           }
                       } else if ( msg->key.key == XK_t &&
                                   KEYSTATEMASK( msg->key.keystate ) == ControlMask ) {
                           m_ignore_date_for_sorting = ! m_ignore_date_for_sorting;
                           m_ignore_date_cb->setState( m_ignore_date_for_sorting );
-                          apply_filter( m_filter );
-                          showData();
+                          apply_filter( m_filter, [this]( int matches ) {
+                                  showData();
+                              });
                       } else if ( msg->key.key == XK_f &&
                            KEYSTATEMASK( msg->key.keystate ) == ControlMask ) {
                           switch ( m_entry_filter_mode ) {
@@ -548,37 +569,40 @@ int PathJumpUI::mainLoop()
                                   m_filter_mode_cyb->setOption( 1 );
                                   break;
                           }
-                          apply_filter( m_filter );
-                          showData();
+                          apply_filter( m_filter, [this]( int matches ) {
+                                  showData();
+                              });
                       } else if ( msg->key.key == XK_h &&
                                   KEYSTATEMASK( msg->key.keystate ) == ControlMask ) {
                           m_entry_filter_age += 1 * 60 * 60;
 
-                          apply_filter( m_filter );
-                          showData();
-                          updateAgeText();
+                          apply_filter( m_filter, [this]( int matches ) {
+                                  showData();
+                                  updateAgeText();
+                              });
                       } else if ( msg->key.key == XK_d &&
                                   KEYSTATEMASK( msg->key.keystate ) == ControlMask ) {
                           m_entry_filter_age += 1 * 24 * 60 * 60;
 
-                          apply_filter( m_filter );
-                          showData();
-                          updateAgeText();
+                          apply_filter( m_filter, [this]( int matches ) {
+                                  showData();
+                                  updateAgeText();
+                              });
                       } else if ( msg->key.key == XK_w &&
                                   KEYSTATEMASK( msg->key.keystate ) == ControlMask ) {
                           m_entry_filter_age += 7 * 24 * 60 * 60;
 
-                          apply_filter( m_filter );
-                          showData();
-                          updateAgeText();
+                          apply_filter( m_filter, [this]( int matches ) {
+                                  showData();
+                                  updateAgeText();
+                              });
                       } else {
                           std::string cur_infix = m_filter;
                           cur_infix += msg->key.keybuf;
-                          if ( apply_filter( cur_infix ) > 0 ) {
-                              m_filter = cur_infix;
-                              apply_filter( m_filter );
-                              showData();
-                          }
+
+                          apply_filter( cur_infix, [this]( int matches ) {
+                                  showData();
+                              });
                       }
                   }
                   break;
@@ -601,12 +625,14 @@ int PathJumpUI::mainLoop()
                 case AG_CHOOSECLICKED:
                     if ( msg->choose.button == m_show_all_cb ) {
                         m_show_hidden_entries = msg->choose.state;
-                        apply_filter( m_filter );
-                        showData();
+                        apply_filter( m_filter, [this]( int matches ) {
+                                showData();
+                            });
                     } else if ( msg->choose.button == m_ignore_date_cb ) {
                         m_ignore_date_for_sorting = m_ignore_date_cb->getState();
-                        apply_filter( m_filter );
-                        showData();
+                        apply_filter( m_filter, [this]( int matches ) {
+                                showData();
+                            });
                     }
                     break;
                 case AG_CYCLEBUTTONCLICKED:
@@ -622,13 +648,18 @@ int PathJumpUI::mainLoop()
                                 m_entry_filter_mode = SHOW_ALL;
                                 break;
                         }
-                        apply_filter( m_filter );
-                        showData();
+                        apply_filter( m_filter, [this]( int matches ) {
+                                showData();
+                            });
                     }
                     break;
             }
             m_aguix.ReplyMessage( msg );
         }
+
+        if ( ! m_apply_state.done ) {
+            apply_filter_next();
+        }
     }
 
     m_selected_path = "";
@@ -637,6 +668,11 @@ int PathJumpUI::mainLoop()
     } else if ( endmode == 1 ) {
         std::string res = "";
 
+        // finalize running filter
+        while ( ! m_apply_state.done ) {
+            apply_filter_next();
+        }
+
         if ( m_current_depth <= 0 ) {
             res = "/";
         } else {
@@ -682,8 +718,6 @@ void PathJumpUI::showData()
 {
     m_ondemand_info.matcher.setMatchString( m_filter );
 
-    m_infixtext->setText( m_filter.c_str() );
-
     if ( m_lv_dirty ||
          m_entry_filter_mode == SHOW_ONLY_DIRECT_SUBDIRS ) {
 
@@ -859,71 +893,88 @@ void PathJumpUI::highlight_best_hit( const std::string &filter )
     showData();
 }
 
-int PathJumpUI::apply_filter( const std::string &filter )
+void PathJumpUI::apply_filter( const std::string filter,
+                               std::function< void( int ) > finalize )
 {
-    int matches = 0;
+    m_apply_state = apply_filter_state();
 
-    StringMatcherFlexibleMatch flmatch;
-    StringMatcherFNMatch match;
-    bool use_flexible = true;
+    m_filter = filter;
 
-    flmatch.setMatchString( filter );
-    flmatch.setMatchCaseSensitive( false );
+    std::string visible_filter = m_filter;
+    visible_filter += "...";
+    m_infixtext->setText( visible_filter.c_str() );
 
-    std::string flexible_string_filter = "*" + StringMatcherFNMatch::convertMatchStringToFlexibleMatch( filter ) + "*";
-    StringMatcherFNMatch flprematcher;
+    m_apply_state.flmatch.setMatchString( filter );
+    m_apply_state.flmatch.setMatchCaseSensitive( false );
 
-    flprematcher.setMatchString( flexible_string_filter );
-    flprematcher.setMatchCaseSensitive( false );
+    m_apply_state.flexible_string_filter = "*" + StringMatcherFNMatch::convertMatchStringToFlexibleMatch( filter ) + "*";
+
+    m_apply_state.flprematcher.setMatchString( m_apply_state.flexible_string_filter );
+    m_apply_state.flprematcher.setMatchCaseSensitive( false );
+
+    m_apply_state.finalize = finalize;
 
     if ( filter.find( "*" ) != std::string::npos ) {
         std::string real_filter = "*";
         real_filter += filter;
         real_filter += "*";
 
-        match.setMatchString( real_filter );
-        match.setMatchCaseSensitive( false );
+        m_apply_state.match.setMatchString( real_filter );
+        m_apply_state.match.setMatchCaseSensitive( false );
 
-        use_flexible = false;
+        m_apply_state.use_flexible = false;
     }
 
-    int exact_path_matches = 0, exact_bookmark_matches = 0,
-        path_matches = 0, bookmark_matches = 0;
-    bool prefer_exact_matches = false;
+    m_apply_state.it1 = m_entries.begin();
 
-    for ( auto it1 = m_entries.begin();
-          it1 != m_entries.end();
-          it1++ ) {
-        if ( it1->m_always_ignore ) continue;
+    m_apply_state.filter = filter;
+}
 
-        if ( use_flexible ) {
+void PathJumpUI::apply_filter_next()
+{
+    if ( m_apply_state.done == true ) {
+        return;
+    }
+    
+    if ( m_apply_state.it1 != m_entries.end() ) {
+        if ( m_apply_state.it1->m_always_ignore ) {
+            m_apply_state.it1++;
+
+            return;
+        }
+
+        if ( m_apply_state.use_flexible ) {
             // check with fnmatch first which is faster than the flexiblematcher but can't return the blockcount
-            if ( flprematcher.match( it1->m_path ) ) {
-                it1->m_blockcount = flmatch.countNonMatchingBlocks<false>( it1->m_path, NULL );
+            if ( m_apply_state.flprematcher.match( m_apply_state.it1->m_path ) ) {
+                m_apply_state.it1->m_blockcount = m_apply_state.flmatch.countNonMatchingBlocks<false>( m_apply_state.it1->m_path, NULL );
             } else {
-                it1->m_blockcount = -1;
+                m_apply_state.it1->m_blockcount = -1;
             }
         } else {
-            it1->m_blockcount = match.match( it1->m_path ) ? 0 : -1;
+            m_apply_state.it1->m_blockcount = m_apply_state.match.match( m_apply_state.it1->m_path ) ? 0 : -1;
         }
 
-        if ( it1->m_blockcount == 0 ) {
-            if ( it1->m_type == PATH_SHOW ||
-                 it1->m_type == PATH_HIDE ) {
-                exact_path_matches++;
-                path_matches++;
+        if ( m_apply_state.it1->m_blockcount == 0 ) {
+            if ( m_apply_state.it1->m_type == PATH_SHOW ||
+                 m_apply_state.it1->m_type == PATH_HIDE ) {
+                m_apply_state.exact_path_matches++;
+                m_apply_state.path_matches++;
             } else {
-                exact_bookmark_matches++;
-                bookmark_matches++;
+                m_apply_state.exact_bookmark_matches++;
+                m_apply_state.bookmark_matches++;
             }
-        } else if ( it1->m_blockcount > 0 ) {
-            if ( it1->m_type == PATH_SHOW ||
-                 it1->m_type == PATH_HIDE ) {
-                path_matches++;
+        } else if ( m_apply_state.it1->m_blockcount > 0 ) {
+            if ( m_apply_state.it1->m_type == PATH_SHOW ||
+                 m_apply_state.it1->m_type == PATH_HIDE ) {
+                m_apply_state.path_matches++;
             } else {
-                bookmark_matches++;
+                m_apply_state.bookmark_matches++;
             }
         }
+
+        m_apply_state.it1++;
+
+        return;
     }
 
     m_entries.sort( std::bind( pathjump_entry::compare,
@@ -940,21 +991,21 @@ int PathJumpUI::apply_filter( const std::string &filter )
              it1->m_type == PATH_HIDE ) {
             if ( it1->m_blockcount == 0 ||
                  ( it1->m_blockcount > 0 &&
-                   ( ! prefer_exact_matches || ( prefer_exact_matches && exact_path_matches == 0 ) ) ) ) {
+                   ( ! m_apply_state.prefer_exact_matches || ( m_apply_state.prefer_exact_matches && m_apply_state.exact_path_matches == 0 ) ) ) ) {
                 it1->m_type = PATH_SHOW;
-                matches++;
+                m_apply_state.matches++;
             } else {
                 it1->m_type = PATH_HIDE;
             }
         } else {
-            if ( ( path_matches == 0 && ! filter.empty() ) ||
+            if ( ( m_apply_state.path_matches == 0 && ! m_apply_state.filter.empty() ) ||
                  m_show_hidden_entries == true ||
                  m_hold_status.active == true ) {
                 if ( it1->m_blockcount == 0 ||
                      ( it1->m_blockcount > 0 &&
-                       ( ! prefer_exact_matches || ( prefer_exact_matches && exact_bookmark_matches == 0 ) ) ) ) {
+                       ( ! m_apply_state.prefer_exact_matches || ( m_apply_state.prefer_exact_matches && m_apply_state.exact_bookmark_matches == 0 ) ) ) ) {
                     it1->m_type = BOOKMARK_SHOW;
-                    matches++;
+                    m_apply_state.matches++;
                 } else {
                     it1->m_type = BOOKMARK_HIDE;
                 }
@@ -976,16 +1027,22 @@ int PathJumpUI::apply_filter( const std::string &filter )
 
     // avoid calling find_entry when the filter hasn't been changed.
     // that way the current entry and depth does not change
-    if ( filter != m_previous_apply_filter ) {
-        find_entry( m_current_entry, filter );
-        m_previous_apply_filter = filter;
+    if ( m_apply_state.filter != m_previous_apply_filter ) {
+        find_entry( m_current_entry, m_apply_state.filter );
+        m_previous_apply_filter = m_apply_state.filter;
     }
 
     post_filtering();
 
     m_lv_dirty = true;
 
-    return matches;
+    m_apply_state.done = true;
+
+    m_infixtext->setText( m_filter.c_str() );
+
+    if ( m_apply_state.finalize ) {
+        m_apply_state.finalize( m_apply_state.matches );
+    }
 }
 
 int PathJumpUI::find_entry( const std::string &name, const std::string &filter )
@@ -1023,13 +1080,16 @@ int PathJumpUI::find_entry( const std::string &name, const std::string &filter )
         }
     }
 
+    m_current_depth = -1;
 
     if ( ! best_hit.empty() ) {
         std::string f = best_hit;
         f += "*";
         
         m_current_depth = find_best_matching_depth( m_current_entry, f );
-    } else {
+    }
+
+    if ( m_current_depth < 0 ) {
         if ( ! filter.empty() ) {
             m_current_depth = find_best_matching_depth( m_current_entry, filter );
         } else {
@@ -1426,8 +1486,9 @@ void PathJumpUI::resetHeldEntriesAndUpdateUI()
 
     m_win->updateCont();
 
-    apply_filter( m_filter );
-    showData();
+    apply_filter( m_filter, [this]( int matches ) {
+            showData();
+        });
 }
 
 int PathJumpUI::calculateMatchClasses()
@@ -1526,8 +1587,9 @@ int PathJumpUI::holdCurrentEntriesAndUpdateUI( int top_x )
 
     m_filter = "";
 
-    apply_filter( m_filter );
-    showData();
+    apply_filter( m_filter, [this]( int matches ) {
+            showData();
+        });
 
     return res;
 }
@@ -1706,6 +1768,9 @@ void PathJumpUI::checkExistance()
     m_win->setCursor( AGUIX::WAIT_CURSOR );
     m_aguix.Flush();
 
+    // cancel running filter before modifying the list
+    m_apply_state = apply_filter_state();
+
     for ( auto it1 = m_entries.begin();
           it1 != m_entries.end(); ) {
         auto next_it = it1;
@@ -1760,8 +1825,9 @@ void PathJumpUI::checkExistance()
         }
     }
 
-    apply_filter( m_filter );
-    showData();
+    apply_filter( m_filter, [this]( int matches ) {
+            showData();
+        });
 
     m_win->unsetCursor();
 }
