@@ -1,6 +1,6 @@
 /* pers_string_list.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2009 Ralf Hoffmann.
+ * Copyright (C) 2009,2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -106,6 +106,23 @@ bool PersistentStringList::contains( const std::string &v )
     return false;
 }
 
+int PersistentStringList::findPosition( const std::string &v )
+{
+    read();
+
+    int pos = 0;
+
+    for ( auto &it1 : m_list ) {
+        if ( it1 == v ) {
+            return pos;
+        }
+
+        pos++;
+    }
+
+    return -1;
+}
+
 std::list< std::string >::size_type PersistentStringList::size()
 {
     read();
