@@ -1,6 +1,6 @@
 /* reloadop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2004,2011,2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -173,7 +173,7 @@ ReloadOp::configure()
   
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(26))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(26));
-  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr, AWindow::AWINDOW_DIALOG );
+  win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe(tstr);
 
@@ -186,8 +186,8 @@ ReloadOp::configure()
   ac1_1->setMaxSpace( 5 );
   ac1_1->setBorderWidth( 0 );
 
-  ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 339 ), 1 ), 0, 0, cfix );
-  rcyb = (CycleButton*)ac1_1->add( new CycleButton( aguix, 0, 0, 100, 1, 0, 0 ), 1, 0, cincw );
+  ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 339 ) ), 0, 0, cfix );
+  rcyb = (CycleButton*)ac1_1->add( new CycleButton( aguix, 0, 0, 100, 0 ), 1, 0, cincw );
   rcyb->addOption(catalog.getLocale(324));
   rcyb->addOption(catalog.getLocale(325));
   rcyb->addOption(catalog.getLocale(326));
@@ -210,7 +210,7 @@ ReloadOp::configure()
   }
   
   rdscb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, ( reset_dirsizes == true ) ? 1 : 0,
-						     catalog.getLocale( 385 ), LABEL_RIGHT, 1, 0 ), 0, 1, cincwnr );
+						     catalog.getLocale( 385 ), LABEL_RIGHT, 0 ), 0, 1, cincwnr );
 
   kftcb = (ChooseButton*)ac1->add( new ChooseButton( aguix,
                                                      0,
@@ -218,7 +218,6 @@ ReloadOp::configure()
                                                      ( keep_filetypes == true ) ? 1 : 0,
                                                      catalog.getLocale( 434 ),
                                                      LABEL_RIGHT,
-                                                     1,
                                                      0 ), 0, 2, cincwnr  );
   
   AContainer *ac1_2 = ac1->add( new AContainer( win, 2, 1 ), 0, 3 );
@@ -229,15 +228,11 @@ ReloadOp::configure()
                                                 0,
                                                 0,
                                                 catalog.getLocale( 11 ),
-                                                1,
-                                                0,
                                                 0 ), 0, 0, cfix );
   Button *cb = (Button*)ac1_2->add( new Button( aguix,
 						0,
 						0,
 						catalog.getLocale( 8 ),
-						1,
-						0,
 						0 ), 1, 0, cfix );
   
   win->setDoTabCycling( true );
