@@ -1,6 +1,6 @@
 /* renameop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2004,2008,2011 Ralf Hoffmann.
+ * Copyright (C) 2001-2004,2008,2011,2013 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -21,10 +21,11 @@
 
 #include "renameop.h"
 #include "listermode.h"
-#include "normalmode.h"
 #include "worker.h"
 #include "nmspecialsourceext.hh"
 #include "worker_locale.h"
+#include "renameorder.hh"
+#include "virtualdirmode.hh"
 
 const char *RenameOp::name="RenameOp";
 
@@ -65,9 +66,13 @@ RenameOp::run( WPUContext *wpu, ActionMessage *msg )
     if(l1!=NULL) {
       startlister=l1;
       lm1=startlister->getActiveMode();
-      if(lm1!=NULL)
-        if(lm1->isType("NormalMode")==true)
-          normalmoderename( msg );
+      if(lm1!=NULL) {
+          if(dynamic_cast< VirtualDirMode * >( lm1 ) ) {
+              normalmoderename( msg );
+          } else {
+              lm1->not_supported();
+          }
+      }
     }
   }
   return 0;
@@ -82,7 +87,6 @@ RenameOp::getDescription()
 int
 RenameOp::normalmoderename( ActionMessage *am )
 {
-  NormalMode *nm1=NULL;
   ListerMode *lm1=NULL;
   struct NM_renameorder renorder;
   NM_specialsourceExt *specialsource=NULL;
@@ -90,8 +94,6 @@ RenameOp::normalmoderename( ActionMessage *am )
   if(startlister==NULL) return 1;
   lm1=startlister->getActiveMode();
   if(lm1==NULL) return 1;
-  if(lm1->isType("NormalMode")!=true) return 1;
-  nm1=(NormalMode*)lm1;
   
   memset( &renorder, 0, sizeof( renorder ) );
   if(am->mode==am->AM_MODE_ONLYACTIVE)
@@ -111,7 +113,10 @@ RenameOp::normalmoderename( ActionMessage *am )
   } else
     renorder.source=renorder.NM_ALLENTRIES;
 
-  nm1->renamef(&renorder);
+  if ( auto vdm = dynamic_cast< VirtualDirMode * >( lm1 ) ) {
+      vdm->renamef( &renorder );
+  }
+
   if(renorder.source==renorder.NM_SPECIAL) {
     if ( specialsource != NULL ) delete specialsource;
     delete renorder.sources;
