@@ -127,7 +127,8 @@ ScriptOp::run( WPUContext *wpu, ActionMessage *msg )
         std::string res_str;
 
         if ( wpu->parse( push_string, res_str, a_max( EXE_STRING_LEN - 1024, 256 ),
-                         ( ( push_useoutput == true ) ? true : false ) ) == WPUContext::PARSE_SUCCESS ) {
+                         ( ( push_useoutput == true ) ? true : false ),
+                         WPUContext::PERSIST_ALL ) == WPUContext::PARSE_SUCCESS ) {
           if ( push_useoutput == true ) {
             std::unique_ptr<ExeClass> ec( new ExeClass( ExeClass::EXECUTE_NORMAL, msg->getWorker() ) );
             ec->cdDir( wpu->getBaseDir() );
@@ -267,7 +268,8 @@ ScriptOp::run( WPUContext *wpu, ActionMessage *msg )
         if ( progress != NULL ) {
           std::string res_str;
           if ( wpu->parse( progress, res_str, a_max( EXE_STRING_LEN - 1024, 256 ),
-                           ( ( progress_useoutput == true ) ? true : false ) ) == WPUContext::PARSE_SUCCESS ) {
+                           ( ( progress_useoutput == true ) ? true : false ),
+                           WPUContext::PERSIST_ALL ) == WPUContext::PARSE_SUCCESS ) {
             if ( progress_useoutput == true ) {
               std::unique_ptr<ExeClass> ec( new ExeClass( ExeClass::EXECUTE_NORMAL ) );
               ec->cdDir( wpu->getBaseDir() );
@@ -317,7 +319,8 @@ ScriptOp::run( WPUContext *wpu, ActionMessage *msg )
           std::string res_str;
           bool valid = true;
           if ( wpu->parse( wintext, res_str, a_max( EXE_STRING_LEN - 1024, 256 ),
-                           ( ( wintext_useoutput == true ) ? true : false ) ) == WPUContext::PARSE_SUCCESS ) {
+                           ( ( wintext_useoutput == true ) ? true : false ),
+                           WPUContext::PERSIST_ALL ) == WPUContext::PARSE_SUCCESS ) {
             if ( wintext_useoutput == true ) {
               std::unique_ptr<ExeClass> ec( new ExeClass( ExeClass::EXECUTE_NORMAL ) );
               ec->cdDir( wpu->getBaseDir() );
@@ -384,7 +387,8 @@ ScriptOp::run( WPUContext *wpu, ActionMessage *msg )
             std::string res_str;
 
             if ( wpu->parse( m_command_str.c_str(), res_str, a_max( EXE_STRING_LEN - 1024, 256 ),
-                             true ) == WPUContext::PARSE_SUCCESS ) {
+                             true,
+                             WPUContext::PERSIST_ALL ) == WPUContext::PARSE_SUCCESS ) {
                 Lister *l1 = msg->getWorker()->getActiveLister();
                 if ( l1 != NULL ) {
                     ListerMode *lm1 = l1->getActiveMode();
