@@ -1,6 +1,6 @@
 /* searchop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2006-2008,2010-2011,2013 Ralf Hoffmann.
+ * Copyright (C) 2006-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -153,7 +153,7 @@ int SearchOp::configure()
     char *tstr;
     tstr = (char*)_allocsafe( strlen( catalog.getLocale( 293 ) ) + strlen( catalog.getLocaleCom( 50 ) ) + 1 );
     sprintf( tstr, catalog.getLocale( 293 ), catalog.getLocaleCom( 50 ) );
-    win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr, AWindow::AWINDOW_DIALOG );
+    win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
     win->create();
     _freesafe(tstr);
 
@@ -166,7 +166,7 @@ int SearchOp::configure()
     ac1_1->setMaxSpace( 0 );
     ac1_1->setBorderWidth( 0 );
 
-    ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 719 ), 1 ),
+    ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 719 ) ),
                 0, 0, AContainer::CO_FIX );
     sg = (StringGadget*)ac1_1->add( new StringGadget( aguix, 0, 0, 200, _edit_command.c_str(), 0 ),
                                     1, 0, AContainer::CO_INCW );
@@ -174,8 +174,6 @@ int SearchOp::configure()
                                                      0,
                                                      0,
                                                      "F",
-                                                     1,
-                                                     0,
                                                      0 ), 2, 0, AContainer::CO_FIX );
     flagb->resize( flagb->getWidth(), sg->getHeight() );
     ac1_1->readLimits();
@@ -184,8 +182,6 @@ int SearchOp::configure()
                                                     0,
                                                     0,
                                                     catalog.getLocale( 196 ),
-                                                    1,
-                                                    0,
                                                     0 ), 0, 1, AContainer::CO_INCW );
 
     ChooseButton *sprcb = (ChooseButton*)ac1->add( new ChooseButton( aguix,
@@ -193,7 +189,7 @@ int SearchOp::configure()
                                                                      0,
                                                                      _show_prev_results,
                                                                      catalog.getLocale( 746 ),
-                                                                     LABEL_RIGHT, 1, 0 ),
+                                                                     LABEL_RIGHT, 0 ),
                                                    0, 2, AContainer::CO_INCWNR );
 
     AContainer *ac1_2 = ac1->add( new AContainer( win, 2, 1 ), 0, 3 );
@@ -204,15 +200,11 @@ int SearchOp::configure()
                                                   0,
                                                   0,
                                                   catalog.getLocale( 11 ),
-                                                  1,
-                                                  0,
                                                   0 ), 0, 0, AContainer::CO_FIX );
     Button *cb = (Button*)ac1_2->add( new Button( aguix,
                                                   0,
                                                   0,
                                                   catalog.getLocale( 8 ),
-                                                  1,
-                                                  0,
                                                   0 ), 1, 0, AContainer::CO_FIX );
     win->setDoTabCycling( true );
     win->contMaximize( true );
