@@ -385,7 +385,7 @@ public:
         try {
             NWC::VirtualDir &vdir = dynamic_cast<NWC::VirtualDir&>( dir );
             vdir.setSearchSameFS( _search_same_fs );
-        } catch ( std::bad_cast ) {
+        } catch ( std::bad_cast & ) {
         }
         return 0;
     }
