@@ -1,6 +1,6 @@
 /* dirsizeop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2004,2011,2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -109,7 +109,7 @@ void ShowDirCacheOp::showCacheList( ActionMessage *msg )
         cache_entries = vdm->getNameOfCacheEntries();
     }
   
-    win = new AWindow( aguix, 10, 10, 10, 10, 0, catalog.getLocale( 523 ), AWindow::AWINDOW_DIALOG );
+    win = new AWindow( aguix, 10, 10, 10, 10, catalog.getLocale( 523 ), AWindow::AWINDOW_DIALOG );
     win->create();
 
     AContainer *ac1 = win->setContainer( new AContainer( win, 1, 3 ), true );
@@ -117,7 +117,7 @@ void ShowDirCacheOp::showCacheList( ActionMessage *msg )
     ac1->setMaxSpace( 5 );
     ac1->setBorderWidth( 5 );
 
-    ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 524 ), 1 ),
+    ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 524 ) ),
               0, 0, AContainer::CO_INCWNR );
 
     AContainer *ac1_2 = ac1->add( new AContainer( win, 1, 2 ), 0, 1 );
@@ -141,15 +141,11 @@ void ShowDirCacheOp::showCacheList( ActionMessage *msg )
                                                   0,
                                                   0,
                                                   catalog.getLocale( 11 ),
-                                                  1,
-                                                  0,
                                                   0 ), 0, 0, AContainer::CO_FIX );
     Button *cancelb = (Button*)ac1_1->add( new Button( aguix,
                                                        0,
                                                        0,
                                                        catalog.getLocale( 8 ),
-                                                       1,
-                                                       0,
                                                        0 ), 1, 0, AContainer::CO_FIX );
 
     std::string cwd = lm1->getCurrentDirectory();
