@@ -1,6 +1,6 @@
 /* simddop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2004,2011 Ralf Hoffmann.
+ * Copyright (C) 2001-2004,2011,2013 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -21,7 +21,6 @@
 
 #include "simddop.h"
 #include "listermode.h"
-#include "normalmode.h"
 #include "worker.h"
 #include "worker_locale.h"
 
@@ -64,9 +63,9 @@ SimDDOp::run( WPUContext *wpu, ActionMessage *msg )
     if(l1!=NULL) {
       startlister=l1;
       lm1=startlister->getActiveMode();
-      if(lm1!=NULL)
-        if(lm1->isType("NormalMode")==true)
-          normalmodesimdd( msg );
+      if ( lm1 != NULL ) {
+          lm1->runCommand( "simulate_doubleclick" );
+      }
     }
   }
   return 0;
@@ -77,22 +76,3 @@ SimDDOp::getDescription()
 {
   return catalog.getLocaleCom(31);
 }
-
-int
-SimDDOp::normalmodesimdd( ActionMessage *am )
-{
-  NormalMode *nm1=NULL;
-  ListerMode *lm1=NULL;
-  
-  if(startlister==NULL) return 1;
-  lm1=startlister->getActiveMode();
-  if(lm1==NULL) return 1;
-  if(lm1->isType("NormalMode")!=true) return 1;
-  nm1=(NormalMode*)lm1;
-  
-  if((am->mode==am->AM_MODE_ONLYACTIVE)||(am->mode==am->AM_MODE_NORMAL)) {
-    nm1->simdd();
-  }
-  return 0;
-}
-
