@@ -1,6 +1,6 @@
 /* switchbuttonbankop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2011,2013 Ralf Hoffmann.
+ * Copyright (C) 2011-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -103,7 +103,7 @@ int SwitchButtonBankOp::configure()
     tstr = (char*)_allocsafe( strlen( catalog.getLocale( 293 ) ) +
                               strlen( getDescription() ) + 1 );
     sprintf( tstr, catalog.getLocale( 293 ), getDescription() );
-    win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr, AWindow::AWINDOW_DIALOG );
+    win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
     win->create();
     _freesafe( tstr );
 
@@ -116,8 +116,8 @@ int SwitchButtonBankOp::configure()
     ac1_1->setMaxSpace( 5 );
     ac1_1->setBorderWidth( 0 );
 
-    ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 957 ), 1 ), 0, 0, cfix );
-    CycleButton *mode_cb = (CycleButton*)ac1_1->add( new CycleButton( aguix, 0, 0, 100, 1, 0, 0 ), 1, 0, cincw );
+    ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 957 ) ), 0, 0, cfix );
+    CycleButton *mode_cb = (CycleButton*)ac1_1->add( new CycleButton( aguix, 0, 0, 100, 0 ), 1, 0, cincw );
     mode_cb->addOption( catalog.getLocale( 958 ) );
     mode_cb->addOption( catalog.getLocale( 959 ) );
     mode_cb->addOption( catalog.getLocale( 960 ) );
@@ -141,7 +141,7 @@ int SwitchButtonBankOp::configure()
     ac1_3->setMaxSpace( 5 );
     ac1_3->setBorderWidth( 0 );
 
-    ac1_3->add( new Text( aguix, 0, 0, catalog.getLocale( 961 ), 1 ), 0, 0, cfix );
+    ac1_3->add( new Text( aguix, 0, 0, catalog.getLocale( 961 ) ), 0, 0, cfix );
     std::string banknrstr = AGUIXUtils::formatStringToString( "%d", m_bank_nr );
     StringGadget *banknr_sg = (StringGadget*)ac1_3->add( new StringGadget( aguix, 0, 0, 100, banknrstr.c_str(), 0 ), 1, 0, cincw );
 
@@ -153,15 +153,11 @@ int SwitchButtonBankOp::configure()
                                                   0,
                                                   0,
                                                   catalog.getLocale( 11 ),
-                                                  1,
-                                                  0,
                                                   0 ), 0, 0, cfix );
     Button *cb = (Button*)ac1_2->add( new Button( aguix,
                                                   0,
                                                   0,
                                                   catalog.getLocale( 8 ),
-                                                  1,
-                                                  0,
                                                   0 ), 1, 0, cfix );
   
     win->setDoTabCycling( true );
