@@ -214,7 +214,7 @@ int Verzeichnis::sortfunction(void *p1,void *p2,int mode)
                   ft2 = wconfig->getnotyettype();
               }
           }
-          comp = strcmp( ft1->getName(), ft2->getName() );
+          comp = ft1->getName().compare( ft2->getName() );
           if ( comp == 0 )
               comp = strcmp( fe1->name, fe2->name );
           break;
