@@ -388,7 +388,7 @@ void VirtualDirMode::finalizeCopy( std::shared_ptr< CopyState > cs )
                                          if ( fse && fse->getFullname() == removed_entry.first ) {
                                              m_lv->showRow( std::get< 1 > ( *iti2 ) - cs->m_row_adjustment );
 
-                                             ce->hideEntry( std::get< 0 > ( *iti2 ) );
+                                             ce->temporarilyHideEntry( std::get< 0 > ( *iti2 ) );
 
                                              if ( !ce->isRealDir() ) {
                                                  cs->m_ids_to_remove.push_back( std::get< 0 > ( *iti2 ) );
@@ -533,7 +533,7 @@ void VirtualDirMode::process_bg_messages()
                             auto fse = es->getNWCEntry();
 
                             if ( fse && fse->getFullname() == msg.m_source_fullname ) {
-                                deselectEntry( msg.m_id );
+                                setEntrySelectionState( msg.m_id, false );
 
                                 if ( cs->m_insert_elements_into_vdm && ! msg.m_target_fullname.empty() ) {
                                     cs->m_inserts.push_back( msg.m_target_fullname );
@@ -559,7 +559,7 @@ void VirtualDirMode::process_bg_messages()
                             if ( msg.m_res == CopyCore::NM_COPY_OK &&
                                  ( msg.m_is_dir == false || msg.m_dir_error_counter == 0 ) ) {
                                 // success so remove entry
-                                ce->hideEntry( msg.m_id );
+                                ce->temporarilyHideEntry( msg.m_id );
 
                                 if ( !ce->isRealDir() ) {
                                     cs->m_ids_to_remove.push_back( msg.m_id );
