@@ -178,7 +178,7 @@ void VirtualDirMode::deletef( struct deleteorder *delorder )
                                            if ( res == DeleteCore::NM_DELETE_OK &&
                                                 ( cod == NULL || cod->error_counter == 0 ) ) {
                                                // success so remove entry
-                                               ce->hideEntry( id );
+                                               ce->temporarilyHideEntry( id );
 
                                                if ( ! ce->isRealDir() ) {
                                                    ids_to_remove.push_back( id );
