@@ -1,6 +1,6 @@
 /* volumemanagerui.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2009-2013 Ralf Hoffmann.
+ * Copyright (C) 2009-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -51,14 +51,14 @@ VolumeManagerUI::VolumeManagerUI( AGUIX &aguix, HWVolumeManager &hwman ) : m_agu
     m_win = std::unique_ptr<AWindow>( new AWindow( &m_aguix,
                                                    0, 0,
                                                    500, 400,
-                                                   0, catalog.getLocale( 871 ),
+                                                   catalog.getLocale( 871 ),
                                                    AWindow::AWINDOW_DIALOG ) );
     m_win->create();
 
     AContainer *cont0 = m_win->setContainer( new AContainer( m_win.get(), 1, 4 ), true );
     cont0->setMaxSpace( 5 );
     
-    cont0->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 872 ), 1 ),
+    cont0->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 872 ) ),
                 0, 0, AContainer::CO_INCW );
     m_cont2 = cont0->add( new AContainer( m_win.get(), 2, 1 ), 0, 1 );
     m_cont2->setBorderWidth( 0 );
@@ -81,47 +81,41 @@ VolumeManagerUI::VolumeManagerUI( AGUIX &aguix, HWVolumeManager &hwman ) : m_agu
     m_lv->setDisplayFocus( true );
     m_lv->setGlobalFieldSpace( 5 );
 
-    AContainer *cont4 = m_cont2->add( new AContainer( m_win.get(), 1, 6 ), 1, 0 );
+    AContainer *cont4 = m_cont2->add( new AContainer( m_win.get(), 1, 7 ), 1, 0 );
     cont4->setBorderWidth( 0 );
     cont4->setMinSpace( 5 );
     cont4->setMaxSpace( 5 );
     
-    m_mountb = dynamic_cast<Button*>( cont4->add( new Button( &m_aguix, 0, 0, catalog.getLocale( 885 ), 1, 0, 0 ),
+    m_mountb = dynamic_cast<Button*>( cont4->add( new Button( &m_aguix, 0, 0, catalog.getLocale( 885 ), 0 ),
                                                   0, 0, AContainer::CO_FIX ) );
-    m_unmountb = dynamic_cast<Button*>( cont4->add( new Button( &m_aguix, 0, 0, catalog.getLocale( 886 ), 1, 0, 0 ),
+    m_unmountb = dynamic_cast<Button*>( cont4->add( new Button( &m_aguix, 0, 0, catalog.getLocale( 886 ), 0 ),
                                                      0, 1, AContainer::CO_FIX ) );
     m_ejectb = dynamic_cast<Button*>( cont4->add( new Button( &m_aguix, 0, 0,
                                                               catalog.getLocale( 965 ),
                                                               catalog.getLocale( 929 ),
-                                                              1, 1,
-                                                              0, 0,
                                                               0 ),
                                                   0, 2, AContainer::CO_FIX ) );
     m_closetrayb = dynamic_cast<Button*>( cont4->add( new Button( &m_aguix, 0, 0,
                                                                   catalog.getLocale( 966 ),
                                                                   catalog.getLocale( 930 ),
-                                                                  1, 1,
-                                                                  0, 0,
                                                                   0 ),
 						      0, 3, AContainer::CO_FIX ) );
     m_hideb = dynamic_cast<Button*>( cont4->add( new Button( &m_aguix,
                                                              0, 0,
                                                              catalog.getLocale( 887 ),
                                                              catalog.getLocale( 888 ),
-                                                             1, 1,
-                                                             0, 0,
                                                              0 ),
                                                  0, 4, AContainer::CO_FIX ) );
-    m_updateb = dynamic_cast<Button*>( cont4->add( new Button( &m_aguix, 0, 0, catalog.getLocale( 922 ), 1, 0, 0 ),
+    m_updateb = dynamic_cast<Button*>( cont4->add( new Button( &m_aguix, 0, 0, catalog.getLocale( 922 ), 0 ),
 						   0, 5, AContainer::CO_FIX ) );
     AContainer *cont7 = cont0->add( new AContainer( m_win.get(), 2, 1 ), 0, 2 );
     cont7->setBorderWidth( 0 );
     cont7->setMinSpace( 5 );
     cont7->setMaxSpace( 5 );
     
-    cont7->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 876 ), 1 ),
+    cont7->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 876 ) ),
                 0, 0, AContainer::CO_FIX );
-    m_status_tv = new TextView( &m_aguix, 0, 0, 100, 50, 0, "", m_status_info );
+    m_status_tv = new TextView( &m_aguix, 0, 0, 100, 50, "", m_status_info );
     cont7->add( m_status_tv, 1, 0, AContainer::CO_INCW );
     m_status_tv->create();
     m_status_tv->show();
@@ -139,11 +133,11 @@ VolumeManagerUI::VolumeManagerUI( AGUIX &aguix, HWVolumeManager &hwman ) : m_agu
     
     m_okb = dynamic_cast<Button*>( cont10->add( new Button( &m_aguix, 0, 0,
                                                             catalog.getLocale( 877 ),
-                                                            1, 0, 0 ),
+                                                            0 ),
                                                 0, 0, AContainer::CO_FIX ) );
     m_closeb = dynamic_cast<Button*>( cont10->add( new Button( &m_aguix, 0, 0,
                                                                catalog.getLocale( 633 ),
-                                                               1, 0, 0 ),
+                                                               0 ),
                                                    1, 0, AContainer::CO_FIX ) );
    
     m_win->contMaximize( true );
@@ -515,14 +509,14 @@ void VolumeManagerUI::editHideList()
     AWindow *win = new AWindow( &m_aguix,
                                 0, 0,
                                 500, 400,
-                                0, catalog.getLocale( 882 ),
+                                catalog.getLocale( 882 ),
                                 AWindow::AWINDOW_DIALOG );
     win->create();
     
     AContainer *cont0 = win->setContainer( new AContainer( win, 1, 4 ), true );
     cont0->setMaxSpace( 5 );
     
-    cont0->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 883 ), 1 ),
+    cont0->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 883 ) ),
                 0, 0, AContainer::CO_INCW );
     
     FieldListView *lv = dynamic_cast<FieldListView*>( cont0->add( new FieldListView( &m_aguix, 0, 0, 
@@ -543,8 +537,8 @@ void VolumeManagerUI::editHideList()
         }
     }
 
-    Button *remove_b = dynamic_cast<Button*>( cont0->add( new Button( &m_aguix, 0, 0, catalog.getLocale( 884 ), 1, 0, 0 ),
-                                                          0, 2, AContainer::CO_FIX ) );
+    Button *remove_b = dynamic_cast<Button*>( cont0->add( new Button( &m_aguix, 0, 0, catalog.getLocale( 884 ), 0 ),
+                                                          0, 2, AContainer::CO_INCW ) );
     AContainer *cont1 = cont0->add( new AContainer( win, 2, 1 ), 0, 3 );
     cont1->setBorderWidth( 0 );
     cont1->setMinSpace( 5 );
@@ -552,11 +546,11 @@ void VolumeManagerUI::editHideList()
     
     Button *okb = dynamic_cast<Button*>( cont1->add( new Button( &m_aguix, 0, 0,
                                                                  catalog.getLocale( 11 ),
-                                                                 1, 0, 0 ),
+                                                                 0 ),
                                                      0, 0, AContainer::CO_FIX ) );
     Button *cancelb = dynamic_cast<Button*>( cont1->add( new Button( &m_aguix, 0, 0,
                                                                      catalog.getLocale( 8 ),
-                                                                     1, 0, 0 ),
+                                                                     0 ),
                                                          1, 0, AContainer::CO_FIX ) );
     
     win->contMaximize( true );
