@@ -1,6 +1,6 @@
 /* wconfig_layout.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2006,2009,2011 Ralf Hoffmann.
+ * Copyright (C) 2006-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -156,7 +156,7 @@ int LayoutPanel::create()
                     0, 0,
                     NULL, NULL );
   
-  ac1->add( new Text( _aguix, 0, 0, catalog.getLocale( 565 ), 1 ), 0, 1, AContainer::CO_INCWNR );
+  ac1->add( new Text( _aguix, 0, 0, catalog.getLocale( 565 ) ), 0, 1, AContainer::CO_INCWNR );
   // sub container 2x2 for lister config
   ac2 = ac1->add( new AContainer( this, 2, 2 ), 0, 2 );
   ac2->setMaxSpace( 5 );
@@ -170,7 +170,6 @@ int LayoutPanel::create()
                                                    ( bv == true ) ? 1 : 0,
                                                    catalog.getLocale( 567 ),
                                                    LABEL_RIGHT,
-                                                   1,
                                                    0 ), 0, 0, AContainer::CO_INCWNR );
   cb1->connect( this );
   cb2 = (ChooseButton*)ac2->add( new ChooseButton( _aguix,
@@ -181,7 +180,6 @@ int LayoutPanel::create()
                                                    ( lvv == true ) ? 1 : 0,
                                                    catalog.getLocale( 568 ),
                                                    LABEL_RIGHT,
-                                                   1,
                                                    0 ), 1, 0, AContainer::CO_INCWNR );
   cb2->connect( this );
 
@@ -206,7 +204,7 @@ int LayoutPanel::create()
   m_available_elements_ac->setMaxSpace( 0 );
   m_available_elements_ac->setMinSpace( 0 );
   m_available_elements_ac->setBorderWidth( 0 );
-  m_available_elements_ac->add( new SolidButton( _aguix, 0, 0, catalog.getLocale( 857 ), 1, 0, false ),
+  m_available_elements_ac->add( new SolidButton( _aguix, 0, 0, catalog.getLocale( 857 ), false ),
                                 0, 0, AContainer::CO_FIX );
   m_available_elements_lv = (FieldListView*)m_available_elements_ac->add( new FieldListView( _aguix, 0, 0, 100, 10, 0 ),
                                                                           0, 1, AContainer::CO_FIX );
@@ -217,7 +215,7 @@ int LayoutPanel::create()
   m_used_elements_ac->setMaxSpace( 0 );
   m_used_elements_ac->setMinSpace( 0 );
   m_used_elements_ac->setBorderWidth( 0 );
-  m_used_elements_ac->add( new SolidButton( _aguix, 0, 0, catalog.getLocale( 858 ), 1, 0, false ),
+  m_used_elements_ac->add( new SolidButton( _aguix, 0, 0, catalog.getLocale( 858 ), false ),
                            0, 0, AContainer::CO_FIX );
   m_used_elements_lv = (FieldListView*)m_used_elements_ac->add( new FieldListView( _aguix, 0, 0, 100, 10, 0 ),
                                                                 0, 1, AContainer::CO_FIX );
@@ -228,10 +226,10 @@ int LayoutPanel::create()
   m_elements_example_ac1_2->setMaxSpace( 0 );
   m_elements_example_ac1_2->setMinSpace( 0 );
   m_elements_example_ac1_2->setBorderWidth( 0 );
-  m_add_element_b = (Button*)m_elements_example_ac1_2->add( new Button( _aguix, 0, 0, catalog.getLocale( 859 ), 1, 0, 0 ),
+  m_add_element_b = (Button*)m_elements_example_ac1_2->add( new Button( _aguix, 0, 0, catalog.getLocale( 859 ), 0 ),
                                                             0, 1, AContainer::CO_FIX );
   m_add_element_b->connect( this );
-  m_remove_element_b = (Button*)m_elements_example_ac1_2->add( new Button( _aguix, 0, 0, catalog.getLocale( 860 ), 1, 0, 0 ),
+  m_remove_element_b = (Button*)m_elements_example_ac1_2->add( new Button( _aguix, 0, 0, catalog.getLocale( 860 ), 0 ),
                                                                0, 3, AContainer::CO_FIX );
   m_remove_element_b->connect( this );
   m_elements_example_ac1_2->setMinHeight( 10, 0, 2 );
@@ -241,14 +239,14 @@ int LayoutPanel::create()
   weight_ac1->setMaxSpace( 5 );
   weight_ac1->setBorderWidth( 0 );
 
-  weight_ac1->add( new Text( _aguix, 0, 0, catalog.getLocale( 861 ), 1 ), 0, 0, AContainer::CO_FIX );
-  m_left_weight_b = (SolidButton*)weight_ac1->add( new SolidButton( _aguix, 0, 0, "000%", 1, 0, true ),
+  weight_ac1->add( new Text( _aguix, 0, 0, catalog.getLocale( 861 ) ), 0, 0, AContainer::CO_FIX );
+  m_left_weight_b = (SolidButton*)weight_ac1->add( new SolidButton( _aguix, 0, 0, "000%", true ),
                                                    1, 0, AContainer::CO_FIX );
   m_weight_sl = (Slider*)weight_ac1->add( new Slider( _aguix, 0, 0, 10, 10, false, 0 ),
                                           2, 0, AContainer::CO_MIN );
   m_weight_sl->setMaxLen( 8 );
   m_weight_sl->connect( this );
-  m_right_weight_b = (SolidButton*)weight_ac1->add( new SolidButton( _aguix, 0, 0, "100%", 1, 0, true ),
+  m_right_weight_b = (SolidButton*)weight_ac1->add( new SolidButton( _aguix, 0, 0, "100%", true ),
                                                     3, 0, AContainer::CO_FIX );
 
   int weight = _baseconfig.getLayoutListViewWeight();
@@ -264,7 +262,6 @@ int LayoutPanel::create()
                                                                   ( _baseconfig.getLayoutWeightRelToActive() == true ) ? 1 : 0,
                                                                   catalog.getLocale( 908 ),
                                                                   LABEL_RIGHT,
-                                                                  1,
                                                                   0 ), 0, 6, AContainer::CO_INCWNR );
 
   setupElementsExample();
@@ -359,7 +356,7 @@ void LayoutPanel::setupExampleContainers()
     m_button_example_ac->setMinSpace( 0 );
 
     while ( m_example_buttons.size() < 6 ) {
-        SolidButton *b = new SolidButton( _aguix, 0, 0, 20, 5, "", 1, 0, 0 );
+        SolidButton *b = new SolidButton( _aguix, 0, 0, 20, 5, "", 0 );
         b->setAcceptFocus( false );
         m_example_buttons.push_back( b );
     }
@@ -385,11 +382,11 @@ void LayoutPanel::setupExampleContainers()
     m_listview_example_ac->setMinSpace( 0 );
 
     if ( m_listview_example_b1 == NULL ) {
-        m_listview_example_b1 = new SolidButton( _aguix, 0, 0, 10, 10, "", 1, 0, 0 );
+        m_listview_example_b1 = new SolidButton( _aguix, 0, 0, 10, 10, "", 0 );
         m_listview_example_b1->setAcceptFocus( false );
     }
     if ( m_listview_example_b2 == NULL ) {
-        m_listview_example_b2 = new SolidButton( _aguix, 0, 0, 10, 10, "", 1, 0, 0 );
+        m_listview_example_b2 = new SolidButton( _aguix, 0, 0, 10, 10, "", 0 );
         m_listview_example_b2->setAcceptFocus( false );
     }
 
@@ -431,28 +428,28 @@ void LayoutPanel::setupElementsExample()
     m_elements_example_ac2->setMinSpace( 0 );
 
     if ( m_example_statebar_b == NULL ) {
-        m_example_statebar_b = new SolidButton( _aguix, 0, 0, 100, 10, "", 1, 0, 0 );
+        m_example_statebar_b = new SolidButton( _aguix, 0, 0, 100, 10, "", 0 );
         m_example_statebar_b->setAcceptFocus( false );
         add( m_example_statebar_b );
     }
     if ( m_example_clockbar_b == NULL ) {
-        m_example_clockbar_b = new SolidButton( _aguix, 0, 0, 100, 10, "", 1, 0, 0 );
+        m_example_clockbar_b = new SolidButton( _aguix, 0, 0, 100, 10, "", 0 );
         m_example_clockbar_b->setAcceptFocus( false );
         add( m_example_clockbar_b );
     }
     if ( m_listview_example2_b1 == NULL ) {
-        m_listview_example2_b1 = new SolidButton( _aguix, 0, 0, 10, 10, "", 1, 0, 0 );
+        m_listview_example2_b1 = new SolidButton( _aguix, 0, 0, 10, 10, "", 0 );
         m_listview_example2_b1->setAcceptFocus( false );
         add( m_listview_example2_b1 );
     }
     if ( m_listview_example2_b2 == NULL ) {
-        m_listview_example2_b2 = new SolidButton( _aguix, 0, 0, 10, 10, "", 1, 0, 0 );
+        m_listview_example2_b2 = new SolidButton( _aguix, 0, 0, 10, 10, "", 0 );
         m_listview_example2_b2->setAcceptFocus( false );
         add( m_listview_example2_b2 );
     }
 
     while ( m_example_buttons2.size() < 6 ) {
-        SolidButton *b = new SolidButton( _aguix, 0, 0, 20, 5, "", 1, 0, 0 );
+        SolidButton *b = new SolidButton( _aguix, 0, 0, 20, 5, "", 0 );
         b->setAcceptFocus( false );
         m_example_buttons2.push_back( b );
         add( b );
