@@ -229,7 +229,7 @@ public:
 
     static mode_t getUMask();
 
-    void openCommandMenu();
+    void openCommandMenu( bool show_recently_used );
 
     worker_version getLastRunningVersion();
     void checkForUpdates( const worker_version &last_running_version,
