@@ -1,6 +1,6 @@
 /* worker_commands.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2016 Ralf Hoffmann.
+ * Copyright (C) 2001-2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -223,6 +223,15 @@ FunctionProto *Worker::getCommand4ID(int id)
     case 65:
       fpr = new ViewNewestFilesOp();
       break;
+    case 66:
+      fpr = new DirCompareOp();
+      break;
+    case 67:
+      fpr = new TabProfilesOp();
+      break;
+    case 68:
+      fpr = new ExternalVDirOp();
+      break;
     default:
       fpr=new DNDAction();
   }
@@ -298,6 +307,9 @@ int Worker::getID4Command(FunctionProto *fpr)
   else if ( fpr->isName( ChTimeOp::name ) == true ) type = 63;
   else if ( fpr->isName( ChangeColumnsOp::name ) == true ) type = 64;
   else if ( fpr->isName( ViewNewestFilesOp::name ) == true ) type = 65;
+  else if ( fpr->isName( DirCompareOp::name ) == true ) type = 66;
+  else if ( fpr->isName( TabProfilesOp::name ) == true ) type = 67;
+  else if ( fpr->isName( ExternalVDirOp::name ) == true ) type = 68;
   return type;
 }
 
