@@ -1,6 +1,6 @@
 /* worker_commands.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2016 Ralf Hoffmann.
+ * Copyright (C) 2001-2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -78,6 +78,12 @@
 
 #include "changecolumnsop.hh"
 
+#include "dircompareop.hh"
+
+#include "tabprofilesop.hh"
+
+#include "externalvdirop.hh"
+
 #endif
 
 /* Local Variables: */
