@@ -27,8 +27,8 @@
 #include "nwc_path.hh"
 #include "datei.h"
 
-#define CATENTRY 1180
-#define CATCOMENTRY 66
+#define CATENTRY 1209
+#define CATCOMENTRY 69
 #define CATFLAGENTRY 59
 
 WorkerLocale catalog;
@@ -1285,6 +1285,36 @@ The default value here is the active entry and it's already correctly protected!
   catalog[1177]=dupstring( "Show non-printable characters as hexadecimal representation\ninstead of a simple dot replacement" );
   catalog[1178]=dupstring( "Show in list view" );
   catalog[1179]=dupstring( "Open a new tab in the current list view and highlight the currently viewed file" );
+  catalog[1180]=dupstring( "Compare the directory in the active and inactive panel based on the criterion selected below. The equal entries will be selected in the active panel (and the unequal entries will be unselected). The inactive panel works inverse, so that all unequal entries will be selected and the equal ones will be unselected. You can also choose to show the results in virtual directories. In this case the active panel will be a virtual directory will all equal files and directories while the inactive panel will be a virtual directory with all unequal elements." );
+  catalog[1181]=dupstring( "How to compare files:" );
+  catalog[1182]=dupstring( "Fast comparison with file size only" );
+  catalog[1183]=dupstring( "Compare size and modification time" );
+  catalog[1184]=dupstring( "Slow comparison with content" );
+  catalog[1185]=dupstring( "How to use result:" );
+  catalog[1186]=dupstring( "Change selection state" );
+  catalog[1187]=dupstring( "Show as virtual directories" );
+  catalog[1188]=dupstring( "Remaining entries to compare:" );
+  catalog[1189]=dupstring( "File compare progress:" );
+  catalog[1190]=dupstring( "Current directory:" );
+  catalog[1191]=dupstring( "%lu of %lu" );
+
+  catalog[1192]=dupstring( "left hand side:" );
+  catalog[1193]=dupstring( "right hand side:" );
+  catalog[1194]=dupstring( "Error writing tab profile %s" );
+  catalog[1195]=dupstring( "Enter a profile name to store currently opened tabs or select a existing profile to restore given set of tabs. You may also choose to remove the profile after opening it successfully." );
+  catalog[1196]=dupstring( "Save tabs currently opened as new profile:" );
+  catalog[1197]=dupstring( "Existing profiles:" );
+  catalog[1198]=dupstring( "Available profiles:" );
+  catalog[1199]=dupstring( "Profile content:" );
+  catalog[1200]=dupstring( "Open" );
+  catalog[1201]=dupstring( "Open and remove" );
+  catalog[1202]=dupstring( "Load" );
+  catalog[1203]=dupstring( "Remove" );
+  catalog[1204]=dupstring( "Invalid profile name %s" );
+  catalog[1205]=dupstring( "Failed to execute the following command:\n%s\nThe return code was:%d\n and the error output was:\n" );
+  catalog[1206]=dupstring( "The given program will be executed and the output lines will be added to a new virtual directory as files. Each output line is considered one file name. Absolute paths will be used as is, relative paths will be interpreted relatively to the current directory." );
+  catalog[1207]=dupstring( "Program and arguments:" );
+  catalog[1208]=dupstring( "State bar font" );
 
 //  catalog[]=dupstring( "" );
   
@@ -1354,6 +1384,9 @@ The default value here is the active entry and it's already correctly protected!
   catalogcom[63]=dupstring( "Change file time" );
   catalogcom[64]=dupstring( "Change columns" );
   catalogcom[65]=dupstring( "View newest files" );
+  catalogcom[66]=dupstring( "Compare directories" );
+  catalogcom[67]=dupstring( "Tab profiles" );
+  catalogcom[68]=dupstring( "External virtual dir" );
   
   catalogflag[0]=dupstring( "String requester" );
   catalogflag[1]=dupstring( "path" );
